# This file is @generated by `scripts/codegen.py namespaces`. Do not edit.

from __future__ import annotations

from typing import TYPE_CHECKING, Literal, NoReturn, final

from monalisten._errors import MonalistenSetupError
from monalisten._namespace import HookNamespace, build_registrar

if TYPE_CHECKING:
    from monalisten import events
    from monalisten._namespace import HookWrapper


class EventNamespace:
    def __call__(self, _: object) -> NoReturn:
        msg = (
            "bare @Monalisten.event is not allowed; to create a hook for all events,"
            " use @Monalisten.event.any"
        )
        raise MonalistenSetupError(msg)

    def __getitem__(self, name: str) -> HookNamespace[NoReturn, events.Any]:
        return getattr(self, name)

    def __init__(self) -> None:  # noqa: PLR0915
        self.any = HookNamespace[Literal["*"], "events.Any"]()
        self.branch_protection_configuration = BranchProtectionConfigurationNamespace()
        self.branch_protection_rule = BranchProtectionRuleNamespace()
        self.check_run = CheckRunNamespace()
        self.check_suite = CheckSuiteNamespace()
        self.code_scanning_alert = CodeScanningAlertNamespace()
        self.commit_comment = CommitCommentNamespace()
        self.create = CreateNamespace()
        self.custom_property = CustomPropertyNamespace()
        self.custom_property_values = CustomPropertyValuesNamespace()
        self.delete = DeleteNamespace()
        self.dependabot_alert = DependabotAlertNamespace()
        self.deploy_key = DeployKeyNamespace()
        self.deployment = DeploymentNamespace()
        self.deployment_protection_rule = DeploymentProtectionRuleNamespace()
        self.deployment_review = DeploymentReviewNamespace()
        self.deployment_status = DeploymentStatusNamespace()
        self.discussion = DiscussionNamespace()
        self.discussion_comment = DiscussionCommentNamespace()
        self.fork = ForkNamespace()
        self.github_app_authorization = GithubAppAuthorizationNamespace()
        self.gollum = GollumNamespace()
        self.installation = InstallationNamespace()
        self.installation_repositories = InstallationRepositoriesNamespace()
        self.installation_target = InstallationTargetNamespace()
        self.issue_comment = IssueCommentNamespace()
        self.issue_dependencies = IssueDependenciesNamespace()
        self.issues = IssuesNamespace()
        self.label = LabelNamespace()
        self.marketplace_purchase = MarketplacePurchaseNamespace()
        self.member = MemberNamespace()
        self.membership = MembershipNamespace()
        self.merge_group = MergeGroupNamespace()
        self.meta = MetaNamespace()
        self.milestone = MilestoneNamespace()
        self.org_block = OrgBlockNamespace()
        self.organization = OrganizationNamespace()
        self.package = PackageNamespace()
        self.page_build = PageBuildNamespace()
        self.personal_access_token_request = PersonalAccessTokenRequestNamespace()
        self.ping = PingNamespace()
        self.project_card = ProjectCardNamespace()
        self.project = ProjectNamespace()
        self.project_column = ProjectColumnNamespace()
        self.projects_v2 = ProjectsV2Namespace()
        self.projects_v2_item = ProjectsV2ItemNamespace()
        self.projects_v2_status_update = ProjectsV2StatusUpdateNamespace()
        self.public = PublicNamespace()
        self.pull_request = PullRequestNamespace()
        self.pull_request_review_comment = PullRequestReviewCommentNamespace()
        self.pull_request_review = PullRequestReviewNamespace()
        self.pull_request_review_thread = PullRequestReviewThreadNamespace()
        self.push = PushNamespace()
        self.registry_package = RegistryPackageNamespace()
        self.release = ReleaseNamespace()
        self.repository_advisory = RepositoryAdvisoryNamespace()
        self.repository = RepositoryNamespace()
        self.repository_dispatch = RepositoryDispatchNamespace()
        self.repository_import = RepositoryImportNamespace()
        self.repository_ruleset = RepositoryRulesetNamespace()
        self.repository_vulnerability_alert = RepositoryVulnerabilityAlertNamespace()
        self.secret_scanning_alert = SecretScanningAlertNamespace()
        self.secret_scanning_alert_location = SecretScanningAlertLocationNamespace()
        self.secret_scanning_scan = SecretScanningScanNamespace()
        self.security_advisory = SecurityAdvisoryNamespace()
        self.security_and_analysis = SecurityAndAnalysisNamespace()
        self.sponsorship = SponsorshipNamespace()
        self.star = StarNamespace()
        self.status = StatusNamespace()
        self.sub_issues = SubIssuesNamespace()
        self.team_add = TeamAddNamespace()
        self.team = TeamNamespace()
        self.watch = WatchNamespace()
        self.workflow_dispatch = WorkflowDispatchNamespace()
        self.workflow_job = WorkflowJobNamespace()
        self.workflow_run = WorkflowRunNamespace()


BranchProtectionConfigurationActions = Literal["disabled", "enabled"]


@final
class BranchProtectionConfigurationNamespace(
    HookNamespace[
        BranchProtectionConfigurationActions, "events.BranchProtectionConfiguration"
    ]
):
    disabled: HookWrapper[[events.BranchProtectionConfigurationDisabled]] = (
        build_registrar("disabled")
    )
    enabled: HookWrapper[[events.BranchProtectionConfigurationEnabled]] = (
        build_registrar("enabled")
    )


BranchProtectionRuleActions = Literal["created", "deleted", "edited"]


@final
class BranchProtectionRuleNamespace(
    HookNamespace[BranchProtectionRuleActions, "events.BranchProtectionRule"]
):
    created: HookWrapper[[events.BranchProtectionRuleCreated]] = build_registrar(
        "created"
    )
    deleted: HookWrapper[[events.BranchProtectionRuleDeleted]] = build_registrar(
        "deleted"
    )
    edited: HookWrapper[[events.BranchProtectionRuleEdited]] = build_registrar("edited")


CheckRunActions = Literal["completed", "created", "requested_action", "rerequested"]


@final
class CheckRunNamespace(HookNamespace[CheckRunActions, "events.CheckRun"]):
    completed: HookWrapper[[events.CheckRunCompleted]] = build_registrar("completed")
    created: HookWrapper[[events.CheckRunCreated]] = build_registrar("created")
    requested_action: HookWrapper[[events.CheckRunRequestedAction]] = build_registrar(
        "requested_action"
    )
    rerequested: HookWrapper[[events.CheckRunRerequested]] = build_registrar(
        "rerequested"
    )


CheckSuiteActions = Literal["completed", "requested", "rerequested"]


@final
class CheckSuiteNamespace(HookNamespace[CheckSuiteActions, "events.CheckSuite"]):
    completed: HookWrapper[[events.CheckSuiteCompleted]] = build_registrar("completed")
    requested: HookWrapper[[events.CheckSuiteRequested]] = build_registrar("requested")
    rerequested: HookWrapper[[events.CheckSuiteRerequested]] = build_registrar(
        "rerequested"
    )


CodeScanningAlertActions = Literal[
    "appeared_in_branch",
    "closed_by_user",
    "created",
    "fixed",
    "reopened",
    "reopened_by_user",
    "updated_assignment",
]


@final
class CodeScanningAlertNamespace(
    HookNamespace[CodeScanningAlertActions, "events.CodeScanningAlert"]
):
    appeared_in_branch: HookWrapper[[events.CodeScanningAlertAppearedInBranch]] = (
        build_registrar("appeared_in_branch")
    )
    closed_by_user: HookWrapper[[events.CodeScanningAlertClosedByUser]] = (
        build_registrar("closed_by_user")
    )
    created: HookWrapper[[events.CodeScanningAlertCreated]] = build_registrar("created")
    fixed: HookWrapper[[events.CodeScanningAlertFixed]] = build_registrar("fixed")
    reopened: HookWrapper[[events.CodeScanningAlertReopened]] = build_registrar(
        "reopened"
    )
    reopened_by_user: HookWrapper[[events.CodeScanningAlertReopenedByUser]] = (
        build_registrar("reopened_by_user")
    )
    updated_assignment: HookWrapper[[events.CodeScanningAlertUpdatedAssignment]] = (
        build_registrar("updated_assignment")
    )


CommitCommentActions = Literal["created"]


@final
class CommitCommentNamespace(
    HookNamespace[CommitCommentActions, "events.CommitComment"]
):
    created: HookWrapper[[events.CommitCommentCreated]] = build_registrar("created")


@final
class CreateNamespace(HookNamespace[NoReturn, "events.Create"]):
    pass


CustomPropertyActions = Literal[
    "created", "deleted", "promote_to_enterprise", "updated"
]


@final
class CustomPropertyNamespace(
    HookNamespace[CustomPropertyActions, "events.CustomProperty"]
):
    created: HookWrapper[[events.CustomPropertyCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.CustomPropertyDeleted]] = build_registrar("deleted")
    promote_to_enterprise: HookWrapper[[events.CustomPropertyPromoteToEnterprise]] = (
        build_registrar("promote_to_enterprise")
    )
    updated: HookWrapper[[events.CustomPropertyUpdated]] = build_registrar("updated")


CustomPropertyValuesActions = Literal["updated"]


@final
class CustomPropertyValuesNamespace(
    HookNamespace[CustomPropertyValuesActions, "events.CustomPropertyValues"]
):
    updated: HookWrapper[[events.CustomPropertyValuesUpdated]] = build_registrar(
        "updated"
    )


@final
class DeleteNamespace(HookNamespace[NoReturn, "events.Delete"]):
    pass


DependabotAlertActions = Literal[
    "assignees_changed",
    "auto_dismissed",
    "auto_reopened",
    "created",
    "dismissed",
    "fixed",
    "reintroduced",
    "reopened",
]


@final
class DependabotAlertNamespace(
    HookNamespace[DependabotAlertActions, "events.DependabotAlert"]
):
    assignees_changed: HookWrapper[[events.DependabotAlertAssigneesChanged]] = (
        build_registrar("assignees_changed")
    )
    auto_dismissed: HookWrapper[[events.DependabotAlertAutoDismissed]] = (
        build_registrar("auto_dismissed")
    )
    auto_reopened: HookWrapper[[events.DependabotAlertAutoReopened]] = build_registrar(
        "auto_reopened"
    )
    created: HookWrapper[[events.DependabotAlertCreated]] = build_registrar("created")
    dismissed: HookWrapper[[events.DependabotAlertDismissed]] = build_registrar(
        "dismissed"
    )
    fixed: HookWrapper[[events.DependabotAlertFixed]] = build_registrar("fixed")
    reintroduced: HookWrapper[[events.DependabotAlertReintroduced]] = build_registrar(
        "reintroduced"
    )
    reopened: HookWrapper[[events.DependabotAlertReopened]] = build_registrar(
        "reopened"
    )


DeployKeyActions = Literal["created", "deleted"]


@final
class DeployKeyNamespace(HookNamespace[DeployKeyActions, "events.DeployKey"]):
    created: HookWrapper[[events.DeployKeyCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.DeployKeyDeleted]] = build_registrar("deleted")


DeploymentActions = Literal["created"]


@final
class DeploymentNamespace(HookNamespace[DeploymentActions, "events.Deployment"]):
    created: HookWrapper[[events.DeploymentCreated]] = build_registrar("created")


DeploymentProtectionRuleActions = Literal["requested"]


@final
class DeploymentProtectionRuleNamespace(
    HookNamespace[DeploymentProtectionRuleActions, "events.DeploymentProtectionRule"]
):
    requested: HookWrapper[[events.DeploymentProtectionRuleRequested]] = (
        build_registrar("requested")
    )


DeploymentReviewActions = Literal["approved", "rejected", "requested"]


@final
class DeploymentReviewNamespace(
    HookNamespace[DeploymentReviewActions, "events.DeploymentReview"]
):
    approved: HookWrapper[[events.DeploymentReviewApproved]] = build_registrar(
        "approved"
    )
    rejected: HookWrapper[[events.DeploymentReviewRejected]] = build_registrar(
        "rejected"
    )
    requested: HookWrapper[[events.DeploymentReviewRequested]] = build_registrar(
        "requested"
    )


DeploymentStatusActions = Literal["created"]


@final
class DeploymentStatusNamespace(
    HookNamespace[DeploymentStatusActions, "events.DeploymentStatus"]
):
    created: HookWrapper[[events.DeploymentStatusCreated]] = build_registrar("created")


DiscussionActions = Literal[
    "answered",
    "category_changed",
    "closed",
    "created",
    "deleted",
    "edited",
    "labeled",
    "locked",
    "pinned",
    "reopened",
    "transferred",
    "unanswered",
    "unlabeled",
    "unlocked",
    "unpinned",
]


@final
class DiscussionNamespace(HookNamespace[DiscussionActions, "events.Discussion"]):
    answered: HookWrapper[[events.DiscussionAnswered]] = build_registrar("answered")
    category_changed: HookWrapper[[events.DiscussionCategoryChanged]] = build_registrar(
        "category_changed"
    )
    closed: HookWrapper[[events.DiscussionClosed]] = build_registrar("closed")
    created: HookWrapper[[events.DiscussionCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.DiscussionDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.DiscussionEdited]] = build_registrar("edited")
    labeled: HookWrapper[[events.DiscussionLabeled]] = build_registrar("labeled")
    locked: HookWrapper[[events.DiscussionLocked]] = build_registrar("locked")
    pinned: HookWrapper[[events.DiscussionPinned]] = build_registrar("pinned")
    reopened: HookWrapper[[events.DiscussionReopened]] = build_registrar("reopened")
    transferred: HookWrapper[[events.DiscussionTransferred]] = build_registrar(
        "transferred"
    )
    unanswered: HookWrapper[[events.DiscussionUnanswered]] = build_registrar(
        "unanswered"
    )
    unlabeled: HookWrapper[[events.DiscussionUnlabeled]] = build_registrar("unlabeled")
    unlocked: HookWrapper[[events.DiscussionUnlocked]] = build_registrar("unlocked")
    unpinned: HookWrapper[[events.DiscussionUnpinned]] = build_registrar("unpinned")


DiscussionCommentActions = Literal["created", "deleted", "edited"]


@final
class DiscussionCommentNamespace(
    HookNamespace[DiscussionCommentActions, "events.DiscussionComment"]
):
    created: HookWrapper[[events.DiscussionCommentCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.DiscussionCommentDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.DiscussionCommentEdited]] = build_registrar("edited")


@final
class ForkNamespace(HookNamespace[NoReturn, "events.Fork"]):
    pass


GithubAppAuthorizationActions = Literal["revoked"]


@final
class GithubAppAuthorizationNamespace(
    HookNamespace[GithubAppAuthorizationActions, "events.GithubAppAuthorization"]
):
    revoked: HookWrapper[[events.GithubAppAuthorizationRevoked]] = build_registrar(
        "revoked"
    )


@final
class GollumNamespace(HookNamespace[NoReturn, "events.Gollum"]):
    pass


InstallationActions = Literal[
    "created", "deleted", "new_permissions_accepted", "suspend", "unsuspend"
]


@final
class InstallationNamespace(HookNamespace[InstallationActions, "events.Installation"]):
    created: HookWrapper[[events.InstallationCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.InstallationDeleted]] = build_registrar("deleted")
    new_permissions_accepted: HookWrapper[
        [events.InstallationNewPermissionsAccepted]
    ] = build_registrar("new_permissions_accepted")
    suspend: HookWrapper[[events.InstallationSuspend]] = build_registrar("suspend")
    unsuspend: HookWrapper[[events.InstallationUnsuspend]] = build_registrar(
        "unsuspend"
    )


InstallationRepositoriesActions = Literal["added", "removed"]


@final
class InstallationRepositoriesNamespace(
    HookNamespace[InstallationRepositoriesActions, "events.InstallationRepositories"]
):
    added: HookWrapper[[events.InstallationRepositoriesAdded]] = build_registrar(
        "added"
    )
    removed: HookWrapper[[events.InstallationRepositoriesRemoved]] = build_registrar(
        "removed"
    )


InstallationTargetActions = Literal["renamed"]


@final
class InstallationTargetNamespace(
    HookNamespace[InstallationTargetActions, "events.InstallationTarget"]
):
    renamed: HookWrapper[[events.InstallationTargetRenamed]] = build_registrar(
        "renamed"
    )


IssueCommentActions = Literal["created", "deleted", "edited", "pinned", "unpinned"]


@final
class IssueCommentNamespace(HookNamespace[IssueCommentActions, "events.IssueComment"]):
    created: HookWrapper[[events.IssueCommentCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.IssueCommentDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.IssueCommentEdited]] = build_registrar("edited")
    pinned: HookWrapper[[events.IssueCommentPinned]] = build_registrar("pinned")
    unpinned: HookWrapper[[events.IssueCommentUnpinned]] = build_registrar("unpinned")


IssueDependenciesActions = Literal[
    "blocked_by_added", "blocked_by_removed", "blocking_added", "blocking_removed"
]


@final
class IssueDependenciesNamespace(
    HookNamespace[IssueDependenciesActions, "events.IssueDependencies"]
):
    blocked_by_added: HookWrapper[[events.IssueDependenciesBlockedByAdded]] = (
        build_registrar("blocked_by_added")
    )
    blocked_by_removed: HookWrapper[[events.IssueDependenciesBlockedByRemoved]] = (
        build_registrar("blocked_by_removed")
    )
    blocking_added: HookWrapper[[events.IssueDependenciesBlockingAdded]] = (
        build_registrar("blocking_added")
    )
    blocking_removed: HookWrapper[[events.IssueDependenciesBlockingRemoved]] = (
        build_registrar("blocking_removed")
    )


IssuesActions = Literal[
    "assigned",
    "closed",
    "deleted",
    "demilestoned",
    "edited",
    "labeled",
    "locked",
    "milestoned",
    "opened",
    "pinned",
    "reopened",
    "transferred",
    "typed",
    "unassigned",
    "unlabeled",
    "unlocked",
    "unpinned",
    "untyped",
]


@final
class IssuesNamespace(HookNamespace[IssuesActions, "events.Issues"]):
    assigned: HookWrapper[[events.IssuesAssigned]] = build_registrar("assigned")
    closed: HookWrapper[[events.IssuesClosed]] = build_registrar("closed")
    deleted: HookWrapper[[events.IssuesDeleted]] = build_registrar("deleted")
    demilestoned: HookWrapper[[events.IssuesDemilestoned]] = build_registrar(
        "demilestoned"
    )
    edited: HookWrapper[[events.IssuesEdited]] = build_registrar("edited")
    labeled: HookWrapper[[events.IssuesLabeled]] = build_registrar("labeled")
    locked: HookWrapper[[events.IssuesLocked]] = build_registrar("locked")
    milestoned: HookWrapper[[events.IssuesMilestoned]] = build_registrar("milestoned")
    opened: HookWrapper[[events.IssuesOpened]] = build_registrar("opened")
    pinned: HookWrapper[[events.IssuesPinned]] = build_registrar("pinned")
    reopened: HookWrapper[[events.IssuesReopened]] = build_registrar("reopened")
    transferred: HookWrapper[[events.IssuesTransferred]] = build_registrar(
        "transferred"
    )
    typed: HookWrapper[[events.IssuesTyped]] = build_registrar("typed")
    unassigned: HookWrapper[[events.IssuesUnassigned]] = build_registrar("unassigned")
    unlabeled: HookWrapper[[events.IssuesUnlabeled]] = build_registrar("unlabeled")
    unlocked: HookWrapper[[events.IssuesUnlocked]] = build_registrar("unlocked")
    unpinned: HookWrapper[[events.IssuesUnpinned]] = build_registrar("unpinned")
    untyped: HookWrapper[[events.IssuesUntyped]] = build_registrar("untyped")


LabelActions = Literal["created", "deleted", "edited"]


@final
class LabelNamespace(HookNamespace[LabelActions, "events.Label"]):
    created: HookWrapper[[events.LabelCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.LabelDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.LabelEdited]] = build_registrar("edited")


MarketplacePurchaseActions = Literal[
    "cancelled", "changed", "pending_change", "pending_change_cancelled", "purchased"
]


@final
class MarketplacePurchaseNamespace(
    HookNamespace[MarketplacePurchaseActions, "events.MarketplacePurchase"]
):
    cancelled: HookWrapper[[events.MarketplacePurchaseCancelled]] = build_registrar(
        "cancelled"
    )
    changed: HookWrapper[[events.MarketplacePurchaseChanged]] = build_registrar(
        "changed"
    )
    pending_change: HookWrapper[[events.MarketplacePurchasePendingChange]] = (
        build_registrar("pending_change")
    )
    pending_change_cancelled: HookWrapper[
        [events.MarketplacePurchasePendingChangeCancelled]
    ] = build_registrar("pending_change_cancelled")
    purchased: HookWrapper[[events.MarketplacePurchasePurchased]] = build_registrar(
        "purchased"
    )


MemberActions = Literal["added", "edited", "removed"]


@final
class MemberNamespace(HookNamespace[MemberActions, "events.Member"]):
    added: HookWrapper[[events.MemberAdded]] = build_registrar("added")
    edited: HookWrapper[[events.MemberEdited]] = build_registrar("edited")
    removed: HookWrapper[[events.MemberRemoved]] = build_registrar("removed")


MembershipActions = Literal["added", "removed"]


@final
class MembershipNamespace(HookNamespace[MembershipActions, "events.Membership"]):
    added: HookWrapper[[events.MembershipAdded]] = build_registrar("added")
    removed: HookWrapper[[events.MembershipRemoved]] = build_registrar("removed")


MergeGroupActions = Literal["checks_requested", "destroyed"]


@final
class MergeGroupNamespace(HookNamespace[MergeGroupActions, "events.MergeGroup"]):
    checks_requested: HookWrapper[[events.MergeGroupChecksRequested]] = build_registrar(
        "checks_requested"
    )
    destroyed: HookWrapper[[events.MergeGroupDestroyed]] = build_registrar("destroyed")


MetaActions = Literal["deleted"]


@final
class MetaNamespace(HookNamespace[MetaActions, "events.Meta"]):
    deleted: HookWrapper[[events.MetaDeleted]] = build_registrar("deleted")


MilestoneActions = Literal["closed", "created", "deleted", "edited", "opened"]


@final
class MilestoneNamespace(HookNamespace[MilestoneActions, "events.Milestone"]):
    closed: HookWrapper[[events.MilestoneClosed]] = build_registrar("closed")
    created: HookWrapper[[events.MilestoneCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.MilestoneDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.MilestoneEdited]] = build_registrar("edited")
    opened: HookWrapper[[events.MilestoneOpened]] = build_registrar("opened")


OrgBlockActions = Literal["blocked", "unblocked"]


@final
class OrgBlockNamespace(HookNamespace[OrgBlockActions, "events.OrgBlock"]):
    blocked: HookWrapper[[events.OrgBlockBlocked]] = build_registrar("blocked")
    unblocked: HookWrapper[[events.OrgBlockUnblocked]] = build_registrar("unblocked")


OrganizationActions = Literal[
    "deleted", "member_added", "member_invited", "member_removed", "renamed"
]


@final
class OrganizationNamespace(HookNamespace[OrganizationActions, "events.Organization"]):
    deleted: HookWrapper[[events.OrganizationDeleted]] = build_registrar("deleted")
    member_added: HookWrapper[[events.OrganizationMemberAdded]] = build_registrar(
        "member_added"
    )
    member_invited: HookWrapper[[events.OrganizationMemberInvited]] = build_registrar(
        "member_invited"
    )
    member_removed: HookWrapper[[events.OrganizationMemberRemoved]] = build_registrar(
        "member_removed"
    )
    renamed: HookWrapper[[events.OrganizationRenamed]] = build_registrar("renamed")


PackageActions = Literal["published", "updated"]


@final
class PackageNamespace(HookNamespace[PackageActions, "events.Package"]):
    published: HookWrapper[[events.PackagePublished]] = build_registrar("published")
    updated: HookWrapper[[events.PackageUpdated]] = build_registrar("updated")


@final
class PageBuildNamespace(HookNamespace[NoReturn, "events.PageBuild"]):
    pass


PersonalAccessTokenRequestActions = Literal[
    "approved", "cancelled", "created", "denied"
]


@final
class PersonalAccessTokenRequestNamespace(
    HookNamespace[
        PersonalAccessTokenRequestActions, "events.PersonalAccessTokenRequest"
    ]
):
    approved: HookWrapper[[events.PersonalAccessTokenRequestApproved]] = (
        build_registrar("approved")
    )
    cancelled: HookWrapper[[events.PersonalAccessTokenRequestCancelled]] = (
        build_registrar("cancelled")
    )
    created: HookWrapper[[events.PersonalAccessTokenRequestCreated]] = build_registrar(
        "created"
    )
    denied: HookWrapper[[events.PersonalAccessTokenRequestDenied]] = build_registrar(
        "denied"
    )


@final
class PingNamespace(HookNamespace[NoReturn, "events.Ping"]):
    pass


ProjectCardActions = Literal["converted", "created", "deleted", "edited", "moved"]


@final
class ProjectCardNamespace(HookNamespace[ProjectCardActions, "events.ProjectCard"]):
    converted: HookWrapper[[events.ProjectCardConverted]] = build_registrar("converted")
    created: HookWrapper[[events.ProjectCardCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.ProjectCardDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.ProjectCardEdited]] = build_registrar("edited")
    moved: HookWrapper[[events.ProjectCardMoved]] = build_registrar("moved")


ProjectActions = Literal["closed", "created", "deleted", "edited", "reopened"]


@final
class ProjectNamespace(HookNamespace[ProjectActions, "events.Project"]):
    closed: HookWrapper[[events.ProjectClosed]] = build_registrar("closed")
    created: HookWrapper[[events.ProjectCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.ProjectDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.ProjectEdited]] = build_registrar("edited")
    reopened: HookWrapper[[events.ProjectReopened]] = build_registrar("reopened")


ProjectColumnActions = Literal["created", "deleted", "edited", "moved"]


@final
class ProjectColumnNamespace(
    HookNamespace[ProjectColumnActions, "events.ProjectColumn"]
):
    created: HookWrapper[[events.ProjectColumnCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.ProjectColumnDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.ProjectColumnEdited]] = build_registrar("edited")
    moved: HookWrapper[[events.ProjectColumnMoved]] = build_registrar("moved")


ProjectsV2Actions = Literal["closed", "created", "deleted", "edited", "reopened"]


@final
class ProjectsV2Namespace(HookNamespace[ProjectsV2Actions, "events.ProjectsV2"]):
    closed: HookWrapper[[events.ProjectsV2ProjectClosed]] = build_registrar("closed")
    created: HookWrapper[[events.ProjectsV2ProjectCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.ProjectsV2ProjectDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.ProjectsV2ProjectEdited]] = build_registrar("edited")
    reopened: HookWrapper[[events.ProjectsV2ProjectReopened]] = build_registrar(
        "reopened"
    )


ProjectsV2ItemActions = Literal[
    "archived", "converted", "created", "deleted", "edited", "reordered", "restored"
]


@final
class ProjectsV2ItemNamespace(
    HookNamespace[ProjectsV2ItemActions, "events.ProjectsV2Item"]
):
    archived: HookWrapper[[events.ProjectsV2ItemArchived]] = build_registrar("archived")
    converted: HookWrapper[[events.ProjectsV2ItemConverted]] = build_registrar(
        "converted"
    )
    created: HookWrapper[[events.ProjectsV2ItemCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.ProjectsV2ItemDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.ProjectsV2ItemEdited]] = build_registrar("edited")
    reordered: HookWrapper[[events.ProjectsV2ItemReordered]] = build_registrar(
        "reordered"
    )
    restored: HookWrapper[[events.ProjectsV2ItemRestored]] = build_registrar("restored")


ProjectsV2StatusUpdateActions = Literal["created", "deleted", "edited"]


@final
class ProjectsV2StatusUpdateNamespace(
    HookNamespace[ProjectsV2StatusUpdateActions, "events.ProjectsV2StatusUpdate"]
):
    created: HookWrapper[[events.ProjectsV2StatusUpdateCreated]] = build_registrar(
        "created"
    )
    deleted: HookWrapper[[events.ProjectsV2StatusUpdateDeleted]] = build_registrar(
        "deleted"
    )
    edited: HookWrapper[[events.ProjectsV2StatusUpdateEdited]] = build_registrar(
        "edited"
    )


@final
class PublicNamespace(HookNamespace[NoReturn, "events.Public"]):
    pass


PullRequestActions = Literal[
    "assigned",
    "auto_merge_disabled",
    "auto_merge_enabled",
    "closed",
    "converted_to_draft",
    "demilestoned",
    "dequeued",
    "edited",
    "enqueued",
    "labeled",
    "locked",
    "milestoned",
    "opened",
    "ready_for_review",
    "reopened",
    "review_request_removed",
    "review_requested",
    "synchronize",
    "unassigned",
    "unlabeled",
    "unlocked",
]


@final
class PullRequestNamespace(HookNamespace[PullRequestActions, "events.PullRequest"]):
    assigned: HookWrapper[[events.PullRequestAssigned]] = build_registrar("assigned")
    auto_merge_disabled: HookWrapper[[events.PullRequestAutoMergeDisabled]] = (
        build_registrar("auto_merge_disabled")
    )
    auto_merge_enabled: HookWrapper[[events.PullRequestAutoMergeEnabled]] = (
        build_registrar("auto_merge_enabled")
    )
    closed: HookWrapper[[events.PullRequestClosed]] = build_registrar("closed")
    converted_to_draft: HookWrapper[[events.PullRequestConvertedToDraft]] = (
        build_registrar("converted_to_draft")
    )
    demilestoned: HookWrapper[[events.PullRequestDemilestoned]] = build_registrar(
        "demilestoned"
    )
    dequeued: HookWrapper[[events.PullRequestDequeued]] = build_registrar("dequeued")
    edited: HookWrapper[[events.PullRequestEdited]] = build_registrar("edited")
    enqueued: HookWrapper[[events.PullRequestEnqueued]] = build_registrar("enqueued")
    labeled: HookWrapper[[events.PullRequestLabeled]] = build_registrar("labeled")
    locked: HookWrapper[[events.PullRequestLocked]] = build_registrar("locked")
    milestoned: HookWrapper[[events.PullRequestMilestoned]] = build_registrar(
        "milestoned"
    )
    opened: HookWrapper[[events.PullRequestOpened]] = build_registrar("opened")
    ready_for_review: HookWrapper[[events.PullRequestReadyForReview]] = build_registrar(
        "ready_for_review"
    )
    reopened: HookWrapper[[events.PullRequestReopened]] = build_registrar("reopened")
    review_request_removed: HookWrapper[[events.PullRequestReviewRequestRemoved]] = (
        build_registrar("review_request_removed")
    )
    review_requested: HookWrapper[[events.PullRequestReviewRequested]] = (
        build_registrar("review_requested")
    )
    synchronize: HookWrapper[[events.PullRequestSynchronize]] = build_registrar(
        "synchronize"
    )
    unassigned: HookWrapper[[events.PullRequestUnassigned]] = build_registrar(
        "unassigned"
    )
    unlabeled: HookWrapper[[events.PullRequestUnlabeled]] = build_registrar("unlabeled")
    unlocked: HookWrapper[[events.PullRequestUnlocked]] = build_registrar("unlocked")


PullRequestReviewCommentActions = Literal["created", "deleted", "edited"]


@final
class PullRequestReviewCommentNamespace(
    HookNamespace[PullRequestReviewCommentActions, "events.PullRequestReviewComment"]
):
    created: HookWrapper[[events.PullRequestReviewCommentCreated]] = build_registrar(
        "created"
    )
    deleted: HookWrapper[[events.PullRequestReviewCommentDeleted]] = build_registrar(
        "deleted"
    )
    edited: HookWrapper[[events.PullRequestReviewCommentEdited]] = build_registrar(
        "edited"
    )


PullRequestReviewActions = Literal["dismissed", "edited", "submitted"]


@final
class PullRequestReviewNamespace(
    HookNamespace[PullRequestReviewActions, "events.PullRequestReview"]
):
    dismissed: HookWrapper[[events.PullRequestReviewDismissed]] = build_registrar(
        "dismissed"
    )
    edited: HookWrapper[[events.PullRequestReviewEdited]] = build_registrar("edited")
    submitted: HookWrapper[[events.PullRequestReviewSubmitted]] = build_registrar(
        "submitted"
    )


PullRequestReviewThreadActions = Literal["resolved", "unresolved"]


@final
class PullRequestReviewThreadNamespace(
    HookNamespace[PullRequestReviewThreadActions, "events.PullRequestReviewThread"]
):
    resolved: HookWrapper[[events.PullRequestReviewThreadResolved]] = build_registrar(
        "resolved"
    )
    unresolved: HookWrapper[[events.PullRequestReviewThreadUnresolved]] = (
        build_registrar("unresolved")
    )


@final
class PushNamespace(HookNamespace[NoReturn, "events.Push"]):
    pass


RegistryPackageActions = Literal["published", "updated"]


@final
class RegistryPackageNamespace(
    HookNamespace[RegistryPackageActions, "events.RegistryPackage"]
):
    published: HookWrapper[[events.RegistryPackagePublished]] = build_registrar(
        "published"
    )
    updated: HookWrapper[[events.RegistryPackageUpdated]] = build_registrar("updated")


ReleaseActions = Literal[
    "created",
    "deleted",
    "edited",
    "prereleased",
    "published",
    "released",
    "unpublished",
]


@final
class ReleaseNamespace(HookNamespace[ReleaseActions, "events.Release"]):
    created: HookWrapper[[events.ReleaseCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.ReleaseDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.ReleaseEdited]] = build_registrar("edited")
    prereleased: HookWrapper[[events.ReleasePrereleased]] = build_registrar(
        "prereleased"
    )
    published: HookWrapper[[events.ReleasePublished]] = build_registrar("published")
    released: HookWrapper[[events.ReleaseReleased]] = build_registrar("released")
    unpublished: HookWrapper[[events.ReleaseUnpublished]] = build_registrar(
        "unpublished"
    )


RepositoryAdvisoryActions = Literal["published", "reported"]


@final
class RepositoryAdvisoryNamespace(
    HookNamespace[RepositoryAdvisoryActions, "events.RepositoryAdvisory"]
):
    published: HookWrapper[[events.RepositoryAdvisoryPublished]] = build_registrar(
        "published"
    )
    reported: HookWrapper[[events.RepositoryAdvisoryReported]] = build_registrar(
        "reported"
    )


RepositoryActions = Literal[
    "archived",
    "created",
    "deleted",
    "edited",
    "privatized",
    "publicized",
    "renamed",
    "transferred",
    "unarchived",
]


@final
class RepositoryNamespace(HookNamespace[RepositoryActions, "events.Repository"]):
    archived: HookWrapper[[events.RepositoryArchived]] = build_registrar("archived")
    created: HookWrapper[[events.RepositoryCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.RepositoryDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.RepositoryEdited]] = build_registrar("edited")
    privatized: HookWrapper[[events.RepositoryPrivatized]] = build_registrar(
        "privatized"
    )
    publicized: HookWrapper[[events.RepositoryPublicized]] = build_registrar(
        "publicized"
    )
    renamed: HookWrapper[[events.RepositoryRenamed]] = build_registrar("renamed")
    transferred: HookWrapper[[events.RepositoryTransferred]] = build_registrar(
        "transferred"
    )
    unarchived: HookWrapper[[events.RepositoryUnarchived]] = build_registrar(
        "unarchived"
    )


RepositoryDispatchActions = Literal["sample"]


@final
class RepositoryDispatchNamespace(
    HookNamespace[RepositoryDispatchActions, "events.RepositoryDispatch"]
):
    sample: HookWrapper[[events.RepositoryDispatchSample]] = build_registrar("sample")


@final
class RepositoryImportNamespace(HookNamespace[NoReturn, "events.RepositoryImport"]):
    pass


RepositoryRulesetActions = Literal["created", "deleted", "edited"]


@final
class RepositoryRulesetNamespace(
    HookNamespace[RepositoryRulesetActions, "events.RepositoryRuleset"]
):
    created: HookWrapper[[events.RepositoryRulesetCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.RepositoryRulesetDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.RepositoryRulesetEdited]] = build_registrar("edited")


RepositoryVulnerabilityAlertActions = Literal["create", "dismiss", "reopen", "resolve"]


@final
class RepositoryVulnerabilityAlertNamespace(
    HookNamespace[
        RepositoryVulnerabilityAlertActions, "events.RepositoryVulnerabilityAlert"
    ]
):
    create: HookWrapper[[events.RepositoryVulnerabilityAlertCreate]] = build_registrar(
        "create"
    )
    dismiss: HookWrapper[[events.RepositoryVulnerabilityAlertDismiss]] = (
        build_registrar("dismiss")
    )
    reopen: HookWrapper[[events.RepositoryVulnerabilityAlertReopen]] = build_registrar(
        "reopen"
    )
    resolve: HookWrapper[[events.RepositoryVulnerabilityAlertResolve]] = (
        build_registrar("resolve")
    )


SecretScanningAlertActions = Literal[
    "assigned",
    "created",
    "publicly_leaked",
    "reopened",
    "resolved",
    "unassigned",
    "validated",
]


@final
class SecretScanningAlertNamespace(
    HookNamespace[SecretScanningAlertActions, "events.SecretScanningAlert"]
):
    assigned: HookWrapper[[events.SecretScanningAlertAssigned]] = build_registrar(
        "assigned"
    )
    created: HookWrapper[[events.SecretScanningAlertCreated]] = build_registrar(
        "created"
    )
    publicly_leaked: HookWrapper[[events.SecretScanningAlertPubliclyLeaked]] = (
        build_registrar("publicly_leaked")
    )
    reopened: HookWrapper[[events.SecretScanningAlertReopened]] = build_registrar(
        "reopened"
    )
    resolved: HookWrapper[[events.SecretScanningAlertResolved]] = build_registrar(
        "resolved"
    )
    unassigned: HookWrapper[[events.SecretScanningAlertUnassigned]] = build_registrar(
        "unassigned"
    )
    validated: HookWrapper[[events.SecretScanningAlertValidated]] = build_registrar(
        "validated"
    )


SecretScanningAlertLocationActions = Literal["created"]


@final
class SecretScanningAlertLocationNamespace(
    HookNamespace[
        SecretScanningAlertLocationActions, "events.SecretScanningAlertLocation"
    ]
):
    created: HookWrapper[[events.SecretScanningAlertLocationCreated]] = build_registrar(
        "created"
    )


SecretScanningScanActions = Literal["completed"]


@final
class SecretScanningScanNamespace(
    HookNamespace[SecretScanningScanActions, "events.SecretScanningScan"]
):
    completed: HookWrapper[[events.SecretScanningScanCompleted]] = build_registrar(
        "completed"
    )


SecurityAdvisoryActions = Literal["published", "updated", "withdrawn"]


@final
class SecurityAdvisoryNamespace(
    HookNamespace[SecurityAdvisoryActions, "events.SecurityAdvisory"]
):
    published: HookWrapper[[events.SecurityAdvisoryPublished]] = build_registrar(
        "published"
    )
    updated: HookWrapper[[events.SecurityAdvisoryUpdated]] = build_registrar("updated")
    withdrawn: HookWrapper[[events.SecurityAdvisoryWithdrawn]] = build_registrar(
        "withdrawn"
    )


@final
class SecurityAndAnalysisNamespace(
    HookNamespace[NoReturn, "events.SecurityAndAnalysis"]
):
    pass


SponsorshipActions = Literal[
    "cancelled",
    "created",
    "edited",
    "pending_cancellation",
    "pending_tier_change",
    "tier_changed",
]


@final
class SponsorshipNamespace(HookNamespace[SponsorshipActions, "events.Sponsorship"]):
    cancelled: HookWrapper[[events.SponsorshipCancelled]] = build_registrar("cancelled")
    created: HookWrapper[[events.SponsorshipCreated]] = build_registrar("created")
    edited: HookWrapper[[events.SponsorshipEdited]] = build_registrar("edited")
    pending_cancellation: HookWrapper[[events.SponsorshipPendingCancellation]] = (
        build_registrar("pending_cancellation")
    )
    pending_tier_change: HookWrapper[[events.SponsorshipPendingTierChange]] = (
        build_registrar("pending_tier_change")
    )
    tier_changed: HookWrapper[[events.SponsorshipTierChanged]] = build_registrar(
        "tier_changed"
    )


StarActions = Literal["created", "deleted"]


@final
class StarNamespace(HookNamespace[StarActions, "events.Star"]):
    created: HookWrapper[[events.StarCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.StarDeleted]] = build_registrar("deleted")


@final
class StatusNamespace(HookNamespace[NoReturn, "events.Status"]):
    pass


SubIssuesActions = Literal[
    "parent_issue_added", "parent_issue_removed", "sub_issue_added", "sub_issue_removed"
]


@final
class SubIssuesNamespace(HookNamespace[SubIssuesActions, "events.SubIssues"]):
    parent_issue_added: HookWrapper[[events.SubIssuesParentIssueAdded]] = (
        build_registrar("parent_issue_added")
    )
    parent_issue_removed: HookWrapper[[events.SubIssuesParentIssueRemoved]] = (
        build_registrar("parent_issue_removed")
    )
    sub_issue_added: HookWrapper[[events.SubIssuesSubIssueAdded]] = build_registrar(
        "sub_issue_added"
    )
    sub_issue_removed: HookWrapper[[events.SubIssuesSubIssueRemoved]] = build_registrar(
        "sub_issue_removed"
    )


@final
class TeamAddNamespace(HookNamespace[NoReturn, "events.TeamAdd"]):
    pass


TeamActions = Literal[
    "added_to_repository", "created", "deleted", "edited", "removed_from_repository"
]


@final
class TeamNamespace(HookNamespace[TeamActions, "events.Team"]):
    added_to_repository: HookWrapper[[events.TeamAddedToRepository]] = build_registrar(
        "added_to_repository"
    )
    created: HookWrapper[[events.TeamCreated]] = build_registrar("created")
    deleted: HookWrapper[[events.TeamDeleted]] = build_registrar("deleted")
    edited: HookWrapper[[events.TeamEdited]] = build_registrar("edited")
    removed_from_repository: HookWrapper[[events.TeamRemovedFromRepository]] = (
        build_registrar("removed_from_repository")
    )


WatchActions = Literal["started"]


@final
class WatchNamespace(HookNamespace[WatchActions, "events.Watch"]):
    started: HookWrapper[[events.WatchStarted]] = build_registrar("started")


@final
class WorkflowDispatchNamespace(HookNamespace[NoReturn, "events.WorkflowDispatch"]):
    pass


WorkflowJobActions = Literal["completed", "in_progress", "queued", "waiting"]


@final
class WorkflowJobNamespace(HookNamespace[WorkflowJobActions, "events.WorkflowJob"]):
    completed: HookWrapper[[events.WorkflowJobCompleted]] = build_registrar("completed")
    in_progress: HookWrapper[[events.WorkflowJobInProgress]] = build_registrar(
        "in_progress"
    )
    queued: HookWrapper[[events.WorkflowJobQueued]] = build_registrar("queued")
    waiting: HookWrapper[[events.WorkflowJobWaiting]] = build_registrar("waiting")


WorkflowRunActions = Literal["completed", "in_progress", "requested"]


@final
class WorkflowRunNamespace(HookNamespace[WorkflowRunActions, "events.WorkflowRun"]):
    completed: HookWrapper[[events.WorkflowRunCompleted]] = build_registrar("completed")
    in_progress: HookWrapper[[events.WorkflowRunInProgress]] = build_registrar(
        "in_progress"
    )
    requested: HookWrapper[[events.WorkflowRunRequested]] = build_registrar("requested")



# This file is @generated by `scripts/codegen.py imports`. Do not edit.

from typing import TYPE_CHECKING

from githubkit.versions.latest.models import (
    WebhookPullRequestReviewRequestedOneof0,
    WebhookPullRequestReviewRequestedOneof1,
    WebhookPullRequestReviewRequestRemovedOneof0,
    WebhookPullRequestReviewRequestRemovedOneof1,
)

PullRequestReviewRequested = (
    WebhookPullRequestReviewRequestedOneof0 | WebhookPullRequestReviewRequestedOneof1
)
PullRequestReviewRequestRemoved = (
    WebhookPullRequestReviewRequestRemovedOneof0
    | WebhookPullRequestReviewRequestRemovedOneof1
)

if TYPE_CHECKING:
    from githubkit.versions.latest.webhooks import (  # noqa: I001
        BranchProtectionConfigurationEvent as BranchProtectionConfiguration,
        BranchProtectionRuleEvent as BranchProtectionRule,
        CheckRunEvent as CheckRun,
        CheckSuiteEvent as CheckSuite,
        CodeScanningAlertEvent as CodeScanningAlert,
        CommitCommentEvent as CommitComment,
        CreateEvent as Create,
        CustomPropertyEvent as CustomProperty,
        CustomPropertyValuesEvent as CustomPropertyValues,
        DeleteEvent as Delete,
        DependabotAlertEvent as DependabotAlert,
        DeployKeyEvent as DeployKey,
        DeploymentEvent as Deployment,
        DeploymentProtectionRuleEvent as DeploymentProtectionRule,
        DeploymentReviewEvent as DeploymentReview,
        DeploymentStatusEvent as DeploymentStatus,
        DiscussionCommentEvent as DiscussionComment,
        DiscussionEvent as Discussion,
        ForkEvent as Fork,
        GithubAppAuthorizationEvent as GithubAppAuthorization,
        GollumEvent as Gollum,
        InstallationEvent as Installation,
        InstallationRepositoriesEvent as InstallationRepositories,
        InstallationTargetEvent as InstallationTarget,
        IssueCommentEvent as IssueComment,
        IssueDependenciesEvent as IssueDependencies,
        IssuesEvent as Issues,
        LabelEvent as Label,
        MarketplacePurchaseEvent as MarketplacePurchase,
        MemberEvent as Member,
        MembershipEvent as Membership,
        MergeGroupEvent as MergeGroup,
        MetaEvent as Meta,
        MilestoneEvent as Milestone,
        OrgBlockEvent as OrgBlock,
        OrganizationEvent as Organization,
        PackageEvent as Package,
        PageBuildEvent as PageBuild,
        PersonalAccessTokenRequestEvent as PersonalAccessTokenRequest,
        PingEvent as Ping,
        ProjectCardEvent as ProjectCard,
        ProjectColumnEvent as ProjectColumn,
        ProjectEvent as Project,
        ProjectsV2Event as ProjectsV2,
        ProjectsV2ItemEvent as ProjectsV2Item,
        ProjectsV2StatusUpdateEvent as ProjectsV2StatusUpdate,
        PublicEvent as Public,
        PullRequestEvent as PullRequest,
        PullRequestReviewCommentEvent as PullRequestReviewComment,
        PullRequestReviewEvent as PullRequestReview,
        PullRequestReviewThreadEvent as PullRequestReviewThread,
        PushEvent as Push,
        RegistryPackageEvent as RegistryPackage,
        ReleaseEvent as Release,
        RepositoryAdvisoryEvent as RepositoryAdvisory,
        RepositoryDispatchEvent as RepositoryDispatch,
        RepositoryEvent as Repository,
        RepositoryImportEvent as RepositoryImport,
        RepositoryRulesetEvent as RepositoryRuleset,
        RepositoryVulnerabilityAlertEvent as RepositoryVulnerabilityAlert,
        SecretScanningAlertEvent as SecretScanningAlert,
        SecretScanningAlertLocationEvent as SecretScanningAlertLocation,
        SecretScanningScanEvent as SecretScanningScan,
        SecurityAdvisoryEvent as SecurityAdvisory,
        SecurityAndAnalysisEvent as SecurityAndAnalysis,
        SponsorshipEvent as Sponsorship,
        StarEvent as Star,
        StatusEvent as Status,
        SubIssuesEvent as SubIssues,
        TeamAddEvent as TeamAdd,
        TeamEvent as Team,
        WatchEvent as Watch,
        WebhookEvent as Any,
        WorkflowDispatchEvent as WorkflowDispatch,
        WorkflowJobEvent as WorkflowJob,
        WorkflowRunEvent as WorkflowRun,
    )
    from githubkit.versions.latest.models import (
        WebhookBranchProtectionConfigurationDisabled as BranchProtectionConfigurationDisabled,
        WebhookBranchProtectionConfigurationEnabled as BranchProtectionConfigurationEnabled,
        WebhookBranchProtectionRuleCreated as BranchProtectionRuleCreated,
        WebhookBranchProtectionRuleDeleted as BranchProtectionRuleDeleted,
        WebhookBranchProtectionRuleEdited as BranchProtectionRuleEdited,
        WebhookCheckRunCompleted as CheckRunCompleted,
        WebhookCheckRunCreated as CheckRunCreated,
        WebhookCheckRunRequestedAction as CheckRunRequestedAction,
        WebhookCheckRunRerequested as CheckRunRerequested,
        WebhookCheckSuiteCompleted as CheckSuiteCompleted,
        WebhookCheckSuiteRequested as CheckSuiteRequested,
        WebhookCheckSuiteRerequested as CheckSuiteRerequested,
        WebhookCodeScanningAlertAppearedInBranch as CodeScanningAlertAppearedInBranch,
        WebhookCodeScanningAlertClosedByUser as CodeScanningAlertClosedByUser,
        WebhookCodeScanningAlertCreated as CodeScanningAlertCreated,
        WebhookCodeScanningAlertFixed as CodeScanningAlertFixed,
        WebhookCodeScanningAlertReopened as CodeScanningAlertReopened,
        WebhookCodeScanningAlertReopenedByUser as CodeScanningAlertReopenedByUser,
        WebhookCodeScanningAlertUpdatedAssignment as CodeScanningAlertUpdatedAssignment,
        WebhookCommitCommentCreated as CommitCommentCreated,
        WebhookCustomPropertyCreated as CustomPropertyCreated,
        WebhookCustomPropertyDeleted as CustomPropertyDeleted,
        WebhookCustomPropertyPromotedToEnterprise as CustomPropertyPromoteToEnterprise,
        WebhookCustomPropertyUpdated as CustomPropertyUpdated,
        WebhookCustomPropertyValuesUpdated as CustomPropertyValuesUpdated,
        WebhookDependabotAlertAssigneesChanged as DependabotAlertAssigneesChanged,
        WebhookDependabotAlertAutoDismissed as DependabotAlertAutoDismissed,
        WebhookDependabotAlertAutoReopened as DependabotAlertAutoReopened,
        WebhookDependabotAlertCreated as DependabotAlertCreated,
        WebhookDependabotAlertDismissed as DependabotAlertDismissed,
        WebhookDependabotAlertFixed as DependabotAlertFixed,
        WebhookDependabotAlertReintroduced as DependabotAlertReintroduced,
        WebhookDependabotAlertReopened as DependabotAlertReopened,
        WebhookDeployKeyCreated as DeployKeyCreated,
        WebhookDeployKeyDeleted as DeployKeyDeleted,
        WebhookDeploymentCreated as DeploymentCreated,
        WebhookDeploymentProtectionRuleRequested as DeploymentProtectionRuleRequested,
        WebhookDeploymentReviewApproved as DeploymentReviewApproved,
        WebhookDeploymentReviewRejected as DeploymentReviewRejected,
        WebhookDeploymentReviewRequested as DeploymentReviewRequested,
        WebhookDeploymentStatusCreated as DeploymentStatusCreated,
        WebhookDiscussionAnswered as DiscussionAnswered,
        WebhookDiscussionCategoryChanged as DiscussionCategoryChanged,
        WebhookDiscussionClosed as DiscussionClosed,
        WebhookDiscussionCommentCreated as DiscussionCommentCreated,
        WebhookDiscussionCommentDeleted as DiscussionCommentDeleted,
        WebhookDiscussionCommentEdited as DiscussionCommentEdited,
        WebhookDiscussionCreated as DiscussionCreated,
        WebhookDiscussionDeleted as DiscussionDeleted,
        WebhookDiscussionEdited as DiscussionEdited,
        WebhookDiscussionLabeled as DiscussionLabeled,
        WebhookDiscussionLocked as DiscussionLocked,
        WebhookDiscussionPinned as DiscussionPinned,
        WebhookDiscussionReopened as DiscussionReopened,
        WebhookDiscussionTransferred as DiscussionTransferred,
        WebhookDiscussionUnanswered as DiscussionUnanswered,
        WebhookDiscussionUnlabeled as DiscussionUnlabeled,
        WebhookDiscussionUnlocked as DiscussionUnlocked,
        WebhookDiscussionUnpinned as DiscussionUnpinned,
        WebhookGithubAppAuthorizationRevoked as GithubAppAuthorizationRevoked,
        WebhookInstallationCreated as InstallationCreated,
        WebhookInstallationDeleted as InstallationDeleted,
        WebhookInstallationNewPermissionsAccepted as InstallationNewPermissionsAccepted,
        WebhookInstallationRepositoriesAdded as InstallationRepositoriesAdded,
        WebhookInstallationRepositoriesRemoved as InstallationRepositoriesRemoved,
        WebhookInstallationSuspend as InstallationSuspend,
        WebhookInstallationTargetRenamed as InstallationTargetRenamed,
        WebhookInstallationUnsuspend as InstallationUnsuspend,
        WebhookIssueCommentCreated as IssueCommentCreated,
        WebhookIssueCommentDeleted as IssueCommentDeleted,
        WebhookIssueCommentEdited as IssueCommentEdited,
        WebhookIssueCommentPinned as IssueCommentPinned,
        WebhookIssueCommentUnpinned as IssueCommentUnpinned,
        WebhookIssueDependenciesBlockedByAdded as IssueDependenciesBlockedByAdded,
        WebhookIssueDependenciesBlockedByRemoved as IssueDependenciesBlockedByRemoved,
        WebhookIssueDependenciesBlockingAdded as IssueDependenciesBlockingAdded,
        WebhookIssueDependenciesBlockingRemoved as IssueDependenciesBlockingRemoved,
        WebhookIssuesAssigned as IssuesAssigned,
        WebhookIssuesClosed as IssuesClosed,
        WebhookIssuesDeleted as IssuesDeleted,
        WebhookIssuesDemilestoned as IssuesDemilestoned,
        WebhookIssuesEdited as IssuesEdited,
        WebhookIssuesLabeled as IssuesLabeled,
        WebhookIssuesLocked as IssuesLocked,
        WebhookIssuesMilestoned as IssuesMilestoned,
        WebhookIssuesOpened as IssuesOpened,
        WebhookIssuesPinned as IssuesPinned,
        WebhookIssuesReopened as IssuesReopened,
        WebhookIssuesTransferred as IssuesTransferred,
        WebhookIssuesTyped as IssuesTyped,
        WebhookIssuesUnassigned as IssuesUnassigned,
        WebhookIssuesUnlabeled as IssuesUnlabeled,
        WebhookIssuesUnlocked as IssuesUnlocked,
        WebhookIssuesUnpinned as IssuesUnpinned,
        WebhookIssuesUntyped as IssuesUntyped,
        WebhookLabelCreated as LabelCreated,
        WebhookLabelDeleted as LabelDeleted,
        WebhookLabelEdited as LabelEdited,
        WebhookMarketplacePurchaseCancelled as MarketplacePurchaseCancelled,
        WebhookMarketplacePurchaseChanged as MarketplacePurchaseChanged,
        WebhookMarketplacePurchasePendingChange as MarketplacePurchasePendingChange,
        WebhookMarketplacePurchasePendingChangeCancelled as MarketplacePurchasePendingChangeCancelled,
        WebhookMarketplacePurchasePurchased as MarketplacePurchasePurchased,
        WebhookMemberAdded as MemberAdded,
        WebhookMemberEdited as MemberEdited,
        WebhookMemberRemoved as MemberRemoved,
        WebhookMembershipAdded as MembershipAdded,
        WebhookMembershipRemoved as MembershipRemoved,
        WebhookMergeGroupChecksRequested as MergeGroupChecksRequested,
        WebhookMergeGroupDestroyed as MergeGroupDestroyed,
        WebhookMetaDeleted as MetaDeleted,
        WebhookMilestoneClosed as MilestoneClosed,
        WebhookMilestoneCreated as MilestoneCreated,
        WebhookMilestoneDeleted as MilestoneDeleted,
        WebhookMilestoneEdited as MilestoneEdited,
        WebhookMilestoneOpened as MilestoneOpened,
        WebhookOrgBlockBlocked as OrgBlockBlocked,
        WebhookOrgBlockUnblocked as OrgBlockUnblocked,
        WebhookOrganizationDeleted as OrganizationDeleted,
        WebhookOrganizationMemberAdded as OrganizationMemberAdded,
        WebhookOrganizationMemberInvited as OrganizationMemberInvited,
        WebhookOrganizationMemberRemoved as OrganizationMemberRemoved,
        WebhookOrganizationRenamed as OrganizationRenamed,
        WebhookPackagePublished as PackagePublished,
        WebhookPackageUpdated as PackageUpdated,
        WebhookPersonalAccessTokenRequestApproved as PersonalAccessTokenRequestApproved,
        WebhookPersonalAccessTokenRequestCancelled as PersonalAccessTokenRequestCancelled,
        WebhookPersonalAccessTokenRequestCreated as PersonalAccessTokenRequestCreated,
        WebhookPersonalAccessTokenRequestDenied as PersonalAccessTokenRequestDenied,
        WebhookProjectCardConverted as ProjectCardConverted,
        WebhookProjectCardCreated as ProjectCardCreated,
        WebhookProjectCardDeleted as ProjectCardDeleted,
        WebhookProjectCardEdited as ProjectCardEdited,
        WebhookProjectCardMoved as ProjectCardMoved,
        WebhookProjectClosed as ProjectClosed,
        WebhookProjectColumnCreated as ProjectColumnCreated,
        WebhookProjectColumnDeleted as ProjectColumnDeleted,
        WebhookProjectColumnEdited as ProjectColumnEdited,
        WebhookProjectColumnMoved as ProjectColumnMoved,
        WebhookProjectCreated as ProjectCreated,
        WebhookProjectDeleted as ProjectDeleted,
        WebhookProjectEdited as ProjectEdited,
        WebhookProjectReopened as ProjectReopened,
        WebhookProjectsV2ItemArchived as ProjectsV2ItemArchived,
        WebhookProjectsV2ItemConverted as ProjectsV2ItemConverted,
        WebhookProjectsV2ItemCreated as ProjectsV2ItemCreated,
        WebhookProjectsV2ItemDeleted as ProjectsV2ItemDeleted,
        WebhookProjectsV2ItemEdited as ProjectsV2ItemEdited,
        WebhookProjectsV2ItemReordered as ProjectsV2ItemReordered,
        WebhookProjectsV2ItemRestored as ProjectsV2ItemRestored,
        WebhookProjectsV2ProjectClosed as ProjectsV2ProjectClosed,
        WebhookProjectsV2ProjectCreated as ProjectsV2ProjectCreated,
        WebhookProjectsV2ProjectDeleted as ProjectsV2ProjectDeleted,
        WebhookProjectsV2ProjectEdited as ProjectsV2ProjectEdited,
        WebhookProjectsV2ProjectReopened as ProjectsV2ProjectReopened,
        WebhookProjectsV2StatusUpdateCreated as ProjectsV2StatusUpdateCreated,
        WebhookProjectsV2StatusUpdateDeleted as ProjectsV2StatusUpdateDeleted,
        WebhookProjectsV2StatusUpdateEdited as ProjectsV2StatusUpdateEdited,
        WebhookPullRequestAssigned as PullRequestAssigned,
        WebhookPullRequestAutoMergeDisabled as PullRequestAutoMergeDisabled,
        WebhookPullRequestAutoMergeEnabled as PullRequestAutoMergeEnabled,
        WebhookPullRequestClosed as PullRequestClosed,
        WebhookPullRequestConvertedToDraft as PullRequestConvertedToDraft,
        WebhookPullRequestDemilestoned as PullRequestDemilestoned,
        WebhookPullRequestDequeued as PullRequestDequeued,
        WebhookPullRequestEdited as PullRequestEdited,
        WebhookPullRequestEnqueued as PullRequestEnqueued,
        WebhookPullRequestLabeled as PullRequestLabeled,
        WebhookPullRequestLocked as PullRequestLocked,
        WebhookPullRequestMilestoned as PullRequestMilestoned,
        WebhookPullRequestOpened as PullRequestOpened,
        WebhookPullRequestReadyForReview as PullRequestReadyForReview,
        WebhookPullRequestReopened as PullRequestReopened,
        WebhookPullRequestReviewCommentCreated as PullRequestReviewCommentCreated,
        WebhookPullRequestReviewCommentDeleted as PullRequestReviewCommentDeleted,
        WebhookPullRequestReviewCommentEdited as PullRequestReviewCommentEdited,
        WebhookPullRequestReviewDismissed as PullRequestReviewDismissed,
        WebhookPullRequestReviewEdited as PullRequestReviewEdited,
        WebhookPullRequestReviewSubmitted as PullRequestReviewSubmitted,
        WebhookPullRequestReviewThreadResolved as PullRequestReviewThreadResolved,
        WebhookPullRequestReviewThreadUnresolved as PullRequestReviewThreadUnresolved,
        WebhookPullRequestSynchronize as PullRequestSynchronize,
        WebhookPullRequestUnassigned as PullRequestUnassigned,
        WebhookPullRequestUnlabeled as PullRequestUnlabeled,
        WebhookPullRequestUnlocked as PullRequestUnlocked,
        WebhookRegistryPackagePublished as RegistryPackagePublished,
        WebhookRegistryPackageUpdated as RegistryPackageUpdated,
        WebhookReleaseCreated as ReleaseCreated,
        WebhookReleaseDeleted as ReleaseDeleted,
        WebhookReleaseEdited as ReleaseEdited,
        WebhookReleasePrereleased as ReleasePrereleased,
        WebhookReleasePublished as ReleasePublished,
        WebhookReleaseReleased as ReleaseReleased,
        WebhookReleaseUnpublished as ReleaseUnpublished,
        WebhookRepositoryAdvisoryPublished as RepositoryAdvisoryPublished,
        WebhookRepositoryAdvisoryReported as RepositoryAdvisoryReported,
        WebhookRepositoryArchived as RepositoryArchived,
        WebhookRepositoryCreated as RepositoryCreated,
        WebhookRepositoryDeleted as RepositoryDeleted,
        WebhookRepositoryDispatchSample as RepositoryDispatchSample,
        WebhookRepositoryEdited as RepositoryEdited,
        WebhookRepositoryPrivatized as RepositoryPrivatized,
        WebhookRepositoryPublicized as RepositoryPublicized,
        WebhookRepositoryRenamed as RepositoryRenamed,
        WebhookRepositoryRulesetCreated as RepositoryRulesetCreated,
        WebhookRepositoryRulesetDeleted as RepositoryRulesetDeleted,
        WebhookRepositoryRulesetEdited as RepositoryRulesetEdited,
        WebhookRepositoryTransferred as RepositoryTransferred,
        WebhookRepositoryUnarchived as RepositoryUnarchived,
        WebhookRepositoryVulnerabilityAlertCreate as RepositoryVulnerabilityAlertCreate,
        WebhookRepositoryVulnerabilityAlertDismiss as RepositoryVulnerabilityAlertDismiss,
        WebhookRepositoryVulnerabilityAlertReopen as RepositoryVulnerabilityAlertReopen,
        WebhookRepositoryVulnerabilityAlertResolve as RepositoryVulnerabilityAlertResolve,
        WebhookSecretScanningAlertAssigned as SecretScanningAlertAssigned,
        WebhookSecretScanningAlertCreated as SecretScanningAlertCreated,
        WebhookSecretScanningAlertLocationCreated as SecretScanningAlertLocationCreated,
        WebhookSecretScanningAlertPubliclyLeaked as SecretScanningAlertPubliclyLeaked,
        WebhookSecretScanningAlertReopened as SecretScanningAlertReopened,
        WebhookSecretScanningAlertResolved as SecretScanningAlertResolved,
        WebhookSecretScanningAlertUnassigned as SecretScanningAlertUnassigned,
        WebhookSecretScanningAlertValidated as SecretScanningAlertValidated,
        WebhookSecretScanningScanCompleted as SecretScanningScanCompleted,
        WebhookSecurityAdvisoryPublished as SecurityAdvisoryPublished,
        WebhookSecurityAdvisoryUpdated as SecurityAdvisoryUpdated,
        WebhookSecurityAdvisoryWithdrawn as SecurityAdvisoryWithdrawn,
        WebhookSponsorshipCancelled as SponsorshipCancelled,
        WebhookSponsorshipCreated as SponsorshipCreated,
        WebhookSponsorshipEdited as SponsorshipEdited,
        WebhookSponsorshipPendingCancellation as SponsorshipPendingCancellation,
        WebhookSponsorshipPendingTierChange as SponsorshipPendingTierChange,
        WebhookSponsorshipTierChanged as SponsorshipTierChanged,
        WebhookStarCreated as StarCreated,
        WebhookStarDeleted as StarDeleted,
        WebhookSubIssuesParentIssueAdded as SubIssuesParentIssueAdded,
        WebhookSubIssuesParentIssueRemoved as SubIssuesParentIssueRemoved,
        WebhookSubIssuesSubIssueAdded as SubIssuesSubIssueAdded,
        WebhookSubIssuesSubIssueRemoved as SubIssuesSubIssueRemoved,
        WebhookTeamAddedToRepository as TeamAddedToRepository,
        WebhookTeamCreated as TeamCreated,
        WebhookTeamDeleted as TeamDeleted,
        WebhookTeamEdited as TeamEdited,
        WebhookTeamRemovedFromRepository as TeamRemovedFromRepository,
        WebhookWatchStarted as WatchStarted,
        WebhookWorkflowJobCompleted as WorkflowJobCompleted,
        WebhookWorkflowJobInProgress as WorkflowJobInProgress,
        WebhookWorkflowJobQueued as WorkflowJobQueued,
        WebhookWorkflowJobWaiting as WorkflowJobWaiting,
        WebhookWorkflowRunCompleted as WorkflowRunCompleted,
        WebhookWorkflowRunInProgress as WorkflowRunInProgress,
        WebhookWorkflowRunRequested as WorkflowRunRequested,
    )
else:
    __lazy_vars__ = {
        "__monalisten_sentinel__": ("__monalisten_sentinel__",),
        "BranchProtectionConfigurationEvent": ("BranchProtectionConfiguration",),
        "BranchProtectionRuleEvent": ("BranchProtectionRule",),
        "CheckRunEvent": ("CheckRun",),
        "CheckSuiteEvent": ("CheckSuite",),
        "CodeScanningAlertEvent": ("CodeScanningAlert",),
        "CommitCommentEvent": ("CommitComment",),
        "CreateEvent": ("Create",),
        "CustomPropertyEvent": ("CustomProperty",),
        "CustomPropertyValuesEvent": ("CustomPropertyValues",),
        "DeleteEvent": ("Delete",),
        "DependabotAlertEvent": ("DependabotAlert",),
        "DeployKeyEvent": ("DeployKey",),
        "DeploymentEvent": ("Deployment",),
        "DeploymentProtectionRuleEvent": ("DeploymentProtectionRule",),
        "DeploymentReviewEvent": ("DeploymentReview",),
        "DeploymentStatusEvent": ("DeploymentStatus",),
        "DiscussionCommentEvent": ("DiscussionComment",),
        "DiscussionEvent": ("Discussion",),
        "ForkEvent": ("Fork",),
        "GithubAppAuthorizationEvent": ("GithubAppAuthorization",),
        "GollumEvent": ("Gollum",),
        "InstallationEvent": ("Installation",),
        "InstallationRepositoriesEvent": ("InstallationRepositories",),
        "InstallationTargetEvent": ("InstallationTarget",),
        "IssueCommentEvent": ("IssueComment",),
        "IssueDependenciesEvent": ("IssueDependencies",),
        "IssuesEvent": ("Issues",),
        "LabelEvent": ("Label",),
        "MarketplacePurchaseEvent": ("MarketplacePurchase",),
        "MemberEvent": ("Member",),
        "MembershipEvent": ("Membership",),
        "MergeGroupEvent": ("MergeGroup",),
        "MetaEvent": ("Meta",),
        "MilestoneEvent": ("Milestone",),
        "OrgBlockEvent": ("OrgBlock",),
        "OrganizationEvent": ("Organization",),
        "PackageEvent": ("Package",),
        "PageBuildEvent": ("PageBuild",),
        "PersonalAccessTokenRequestEvent": ("PersonalAccessTokenRequest",),
        "PingEvent": ("Ping",),
        "ProjectCardEvent": ("ProjectCard",),
        "ProjectColumnEvent": ("ProjectColumn",),
        "ProjectEvent": ("Project",),
        "ProjectsV2Event": ("ProjectsV2",),
        "ProjectsV2ItemEvent": ("ProjectsV2Item",),
        "ProjectsV2StatusUpdateEvent": ("ProjectsV2StatusUpdate",),
        "PublicEvent": ("Public",),
        "PullRequestEvent": ("PullRequest",),
        "PullRequestReviewCommentEvent": ("PullRequestReviewComment",),
        "PullRequestReviewEvent": ("PullRequestReview",),
        "PullRequestReviewThreadEvent": ("PullRequestReviewThread",),
        "PushEvent": ("Push",),
        "RegistryPackageEvent": ("RegistryPackage",),
        "ReleaseEvent": ("Release",),
        "RepositoryAdvisoryEvent": ("RepositoryAdvisory",),
        "RepositoryDispatchEvent": ("RepositoryDispatch",),
        "RepositoryEvent": ("Repository",),
        "RepositoryImportEvent": ("RepositoryImport",),
        "RepositoryRulesetEvent": ("RepositoryRuleset",),
        "RepositoryVulnerabilityAlertEvent": ("RepositoryVulnerabilityAlert",),
        "SecretScanningAlertEvent": ("SecretScanningAlert",),
        "SecretScanningAlertLocationEvent": ("SecretScanningAlertLocation",),
        "SecretScanningScanEvent": ("SecretScanningScan",),
        "SecurityAdvisoryEvent": ("SecurityAdvisory",),
        "SecurityAndAnalysisEvent": ("SecurityAndAnalysis",),
        "SponsorshipEvent": ("Sponsorship",),
        "StarEvent": ("Star",),
        "StatusEvent": ("Status",),
        "SubIssuesEvent": ("SubIssues",),
        "TeamAddEvent": ("TeamAdd",),
        "TeamEvent": ("Team",),
        "WatchEvent": ("Watch",),
        "WebhookBranchProtectionConfigurationDisabled": (
            "BranchProtectionConfigurationDisabled",
        ),
        "WebhookBranchProtectionConfigurationEnabled": (
            "BranchProtectionConfigurationEnabled",
        ),
        "WebhookBranchProtectionRuleCreated": ("BranchProtectionRuleCreated",),
        "WebhookBranchProtectionRuleDeleted": ("BranchProtectionRuleDeleted",),
        "WebhookBranchProtectionRuleEdited": ("BranchProtectionRuleEdited",),
        "WebhookCheckRunCompleted": ("CheckRunCompleted",),
        "WebhookCheckRunCreated": ("CheckRunCreated",),
        "WebhookCheckRunRequestedAction": ("CheckRunRequestedAction",),
        "WebhookCheckRunRerequested": ("CheckRunRerequested",),
        "WebhookCheckSuiteCompleted": ("CheckSuiteCompleted",),
        "WebhookCheckSuiteRequested": ("CheckSuiteRequested",),
        "WebhookCheckSuiteRerequested": ("CheckSuiteRerequested",),
        "WebhookCodeScanningAlertAppearedInBranch": (
            "CodeScanningAlertAppearedInBranch",
        ),
        "WebhookCodeScanningAlertClosedByUser": ("CodeScanningAlertClosedByUser",),
        "WebhookCodeScanningAlertCreated": ("CodeScanningAlertCreated",),
        "WebhookCodeScanningAlertFixed": ("CodeScanningAlertFixed",),
        "WebhookCodeScanningAlertReopened": ("CodeScanningAlertReopened",),
        "WebhookCodeScanningAlertReopenedByUser": ("CodeScanningAlertReopenedByUser",),
        "WebhookCodeScanningAlertUpdatedAssignment": (
            "CodeScanningAlertUpdatedAssignment",
        ),
        "WebhookCommitCommentCreated": ("CommitCommentCreated",),
        "WebhookCustomPropertyCreated": ("CustomPropertyCreated",),
        "WebhookCustomPropertyDeleted": ("CustomPropertyDeleted",),
        "WebhookCustomPropertyPromotedToEnterprise": (
            "CustomPropertyPromoteToEnterprise",
        ),
        "WebhookCustomPropertyUpdated": ("CustomPropertyUpdated",),
        "WebhookCustomPropertyValuesUpdated": ("CustomPropertyValuesUpdated",),
        "WebhookDependabotAlertAssigneesChanged": ("DependabotAlertAssigneesChanged",),
        "WebhookDependabotAlertAutoDismissed": ("DependabotAlertAutoDismissed",),
        "WebhookDependabotAlertAutoReopened": ("DependabotAlertAutoReopened",),
        "WebhookDependabotAlertCreated": ("DependabotAlertCreated",),
        "WebhookDependabotAlertDismissed": ("DependabotAlertDismissed",),
        "WebhookDependabotAlertFixed": ("DependabotAlertFixed",),
        "WebhookDependabotAlertReintroduced": ("DependabotAlertReintroduced",),
        "WebhookDependabotAlertReopened": ("DependabotAlertReopened",),
        "WebhookDeployKeyCreated": ("DeployKeyCreated",),
        "WebhookDeployKeyDeleted": ("DeployKeyDeleted",),
        "WebhookDeploymentCreated": ("DeploymentCreated",),
        "WebhookDeploymentProtectionRuleRequested": (
            "DeploymentProtectionRuleRequested",
        ),
        "WebhookDeploymentReviewApproved": ("DeploymentReviewApproved",),
        "WebhookDeploymentReviewRejected": ("DeploymentReviewRejected",),
        "WebhookDeploymentReviewRequested": ("DeploymentReviewRequested",),
        "WebhookDeploymentStatusCreated": ("DeploymentStatusCreated",),
        "WebhookDiscussionAnswered": ("DiscussionAnswered",),
        "WebhookDiscussionCategoryChanged": ("DiscussionCategoryChanged",),
        "WebhookDiscussionClosed": ("DiscussionClosed",),
        "WebhookDiscussionCommentCreated": ("DiscussionCommentCreated",),
        "WebhookDiscussionCommentDeleted": ("DiscussionCommentDeleted",),
        "WebhookDiscussionCommentEdited": ("DiscussionCommentEdited",),
        "WebhookDiscussionCreated": ("DiscussionCreated",),
        "WebhookDiscussionDeleted": ("DiscussionDeleted",),
        "WebhookDiscussionEdited": ("DiscussionEdited",),
        "WebhookDiscussionLabeled": ("DiscussionLabeled",),
        "WebhookDiscussionLocked": ("DiscussionLocked",),
        "WebhookDiscussionPinned": ("DiscussionPinned",),
        "WebhookDiscussionReopened": ("DiscussionReopened",),
        "WebhookDiscussionTransferred": ("DiscussionTransferred",),
        "WebhookDiscussionUnanswered": ("DiscussionUnanswered",),
        "WebhookDiscussionUnlabeled": ("DiscussionUnlabeled",),
        "WebhookDiscussionUnlocked": ("DiscussionUnlocked",),
        "WebhookDiscussionUnpinned": ("DiscussionUnpinned",),
        "WebhookEvent": ("Any",),
        "WebhookGithubAppAuthorizationRevoked": ("GithubAppAuthorizationRevoked",),
        "WebhookInstallationCreated": ("InstallationCreated",),
        "WebhookInstallationDeleted": ("InstallationDeleted",),
        "WebhookInstallationNewPermissionsAccepted": (
            "InstallationNewPermissionsAccepted",
        ),
        "WebhookInstallationRepositoriesAdded": ("InstallationRepositoriesAdded",),
        "WebhookInstallationRepositoriesRemoved": ("InstallationRepositoriesRemoved",),
        "WebhookInstallationSuspend": ("InstallationSuspend",),
        "WebhookInstallationTargetRenamed": ("InstallationTargetRenamed",),
        "WebhookInstallationUnsuspend": ("InstallationUnsuspend",),
        "WebhookIssueCommentCreated": ("IssueCommentCreated",),
        "WebhookIssueCommentDeleted": ("IssueCommentDeleted",),
        "WebhookIssueCommentEdited": ("IssueCommentEdited",),
        "WebhookIssueCommentPinned": ("IssueCommentPinned",),
        "WebhookIssueCommentUnpinned": ("IssueCommentUnpinned",),
        "WebhookIssueDependenciesBlockedByAdded": ("IssueDependenciesBlockedByAdded",),
        "WebhookIssueDependenciesBlockedByRemoved": (
            "IssueDependenciesBlockedByRemoved",
        ),
        "WebhookIssueDependenciesBlockingAdded": ("IssueDependenciesBlockingAdded",),
        "WebhookIssueDependenciesBlockingRemoved": (
            "IssueDependenciesBlockingRemoved",
        ),
        "WebhookIssuesAssigned": ("IssuesAssigned",),
        "WebhookIssuesClosed": ("IssuesClosed",),
        "WebhookIssuesDeleted": ("IssuesDeleted",),
        "WebhookIssuesDemilestoned": ("IssuesDemilestoned",),
        "WebhookIssuesEdited": ("IssuesEdited",),
        "WebhookIssuesLabeled": ("IssuesLabeled",),
        "WebhookIssuesLocked": ("IssuesLocked",),
        "WebhookIssuesMilestoned": ("IssuesMilestoned",),
        "WebhookIssuesOpened": ("IssuesOpened",),
        "WebhookIssuesPinned": ("IssuesPinned",),
        "WebhookIssuesReopened": ("IssuesReopened",),
        "WebhookIssuesTransferred": ("IssuesTransferred",),
        "WebhookIssuesTyped": ("IssuesTyped",),
        "WebhookIssuesUnassigned": ("IssuesUnassigned",),
        "WebhookIssuesUnlabeled": ("IssuesUnlabeled",),
        "WebhookIssuesUnlocked": ("IssuesUnlocked",),
        "WebhookIssuesUnpinned": ("IssuesUnpinned",),
        "WebhookIssuesUntyped": ("IssuesUntyped",),
        "WebhookLabelCreated": ("LabelCreated",),
        "WebhookLabelDeleted": ("LabelDeleted",),
        "WebhookLabelEdited": ("LabelEdited",),
        "WebhookMarketplacePurchaseCancelled": ("MarketplacePurchaseCancelled",),
        "WebhookMarketplacePurchaseChanged": ("MarketplacePurchaseChanged",),
        "WebhookMarketplacePurchasePendingChange": (
            "MarketplacePurchasePendingChange",
        ),
        "WebhookMarketplacePurchasePendingChangeCancelled": (
            "MarketplacePurchasePendingChangeCancelled",
        ),
        "WebhookMarketplacePurchasePurchased": ("MarketplacePurchasePurchased",),
        "WebhookMemberAdded": ("MemberAdded",),
        "WebhookMemberEdited": ("MemberEdited",),
        "WebhookMemberRemoved": ("MemberRemoved",),
        "WebhookMembershipAdded": ("MembershipAdded",),
        "WebhookMembershipRemoved": ("MembershipRemoved",),
        "WebhookMergeGroupChecksRequested": ("MergeGroupChecksRequested",),
        "WebhookMergeGroupDestroyed": ("MergeGroupDestroyed",),
        "WebhookMetaDeleted": ("MetaDeleted",),
        "WebhookMilestoneClosed": ("MilestoneClosed",),
        "WebhookMilestoneCreated": ("MilestoneCreated",),
        "WebhookMilestoneDeleted": ("MilestoneDeleted",),
        "WebhookMilestoneEdited": ("MilestoneEdited",),
        "WebhookMilestoneOpened": ("MilestoneOpened",),
        "WebhookOrgBlockBlocked": ("OrgBlockBlocked",),
        "WebhookOrgBlockUnblocked": ("OrgBlockUnblocked",),
        "WebhookOrganizationDeleted": ("OrganizationDeleted",),
        "WebhookOrganizationMemberAdded": ("OrganizationMemberAdded",),
        "WebhookOrganizationMemberInvited": ("OrganizationMemberInvited",),
        "WebhookOrganizationMemberRemoved": ("OrganizationMemberRemoved",),
        "WebhookOrganizationRenamed": ("OrganizationRenamed",),
        "WebhookPackagePublished": ("PackagePublished",),
        "WebhookPackageUpdated": ("PackageUpdated",),
        "WebhookPersonalAccessTokenRequestApproved": (
            "PersonalAccessTokenRequestApproved",
        ),
        "WebhookPersonalAccessTokenRequestCancelled": (
            "PersonalAccessTokenRequestCancelled",
        ),
        "WebhookPersonalAccessTokenRequestCreated": (
            "PersonalAccessTokenRequestCreated",
        ),
        "WebhookPersonalAccessTokenRequestDenied": (
            "PersonalAccessTokenRequestDenied",
        ),
        "WebhookProjectCardConverted": ("ProjectCardConverted",),
        "WebhookProjectCardCreated": ("ProjectCardCreated",),
        "WebhookProjectCardDeleted": ("ProjectCardDeleted",),
        "WebhookProjectCardEdited": ("ProjectCardEdited",),
        "WebhookProjectCardMoved": ("ProjectCardMoved",),
        "WebhookProjectClosed": ("ProjectClosed",),
        "WebhookProjectColumnCreated": ("ProjectColumnCreated",),
        "WebhookProjectColumnDeleted": ("ProjectColumnDeleted",),
        "WebhookProjectColumnEdited": ("ProjectColumnEdited",),
        "WebhookProjectColumnMoved": ("ProjectColumnMoved",),
        "WebhookProjectCreated": ("ProjectCreated",),
        "WebhookProjectDeleted": ("ProjectDeleted",),
        "WebhookProjectEdited": ("ProjectEdited",),
        "WebhookProjectReopened": ("ProjectReopened",),
        "WebhookProjectsV2ItemArchived": ("ProjectsV2ItemArchived",),
        "WebhookProjectsV2ItemConverted": ("ProjectsV2ItemConverted",),
        "WebhookProjectsV2ItemCreated": ("ProjectsV2ItemCreated",),
        "WebhookProjectsV2ItemDeleted": ("ProjectsV2ItemDeleted",),
        "WebhookProjectsV2ItemEdited": ("ProjectsV2ItemEdited",),
        "WebhookProjectsV2ItemReordered": ("ProjectsV2ItemReordered",),
        "WebhookProjectsV2ItemRestored": ("ProjectsV2ItemRestored",),
        "WebhookProjectsV2ProjectClosed": ("ProjectsV2ProjectClosed",),
        "WebhookProjectsV2ProjectCreated": ("ProjectsV2ProjectCreated",),
        "WebhookProjectsV2ProjectDeleted": ("ProjectsV2ProjectDeleted",),
        "WebhookProjectsV2ProjectEdited": ("ProjectsV2ProjectEdited",),
        "WebhookProjectsV2ProjectReopened": ("ProjectsV2ProjectReopened",),
        "WebhookProjectsV2StatusUpdateCreated": ("ProjectsV2StatusUpdateCreated",),
        "WebhookProjectsV2StatusUpdateDeleted": ("ProjectsV2StatusUpdateDeleted",),
        "WebhookProjectsV2StatusUpdateEdited": ("ProjectsV2StatusUpdateEdited",),
        "WebhookPullRequestAssigned": ("PullRequestAssigned",),
        "WebhookPullRequestAutoMergeDisabled": ("PullRequestAutoMergeDisabled",),
        "WebhookPullRequestAutoMergeEnabled": ("PullRequestAutoMergeEnabled",),
        "WebhookPullRequestClosed": ("PullRequestClosed",),
        "WebhookPullRequestConvertedToDraft": ("PullRequestConvertedToDraft",),
        "WebhookPullRequestDemilestoned": ("PullRequestDemilestoned",),
        "WebhookPullRequestDequeued": ("PullRequestDequeued",),
        "WebhookPullRequestEdited": ("PullRequestEdited",),
        "WebhookPullRequestEnqueued": ("PullRequestEnqueued",),
        "WebhookPullRequestLabeled": ("PullRequestLabeled",),
        "WebhookPullRequestLocked": ("PullRequestLocked",),
        "WebhookPullRequestMilestoned": ("PullRequestMilestoned",),
        "WebhookPullRequestOpened": ("PullRequestOpened",),
        "WebhookPullRequestReadyForReview": ("PullRequestReadyForReview",),
        "WebhookPullRequestReopened": ("PullRequestReopened",),
        "WebhookPullRequestReviewCommentCreated": ("PullRequestReviewCommentCreated",),
        "WebhookPullRequestReviewCommentDeleted": ("PullRequestReviewCommentDeleted",),
        "WebhookPullRequestReviewCommentEdited": ("PullRequestReviewCommentEdited",),
        "WebhookPullRequestReviewDismissed": ("PullRequestReviewDismissed",),
        "WebhookPullRequestReviewEdited": ("PullRequestReviewEdited",),
        "WebhookPullRequestReviewSubmitted": ("PullRequestReviewSubmitted",),
        "WebhookPullRequestReviewThreadResolved": ("PullRequestReviewThreadResolved",),
        "WebhookPullRequestReviewThreadUnresolved": (
            "PullRequestReviewThreadUnresolved",
        ),
        "WebhookPullRequestSynchronize": ("PullRequestSynchronize",),
        "WebhookPullRequestUnassigned": ("PullRequestUnassigned",),
        "WebhookPullRequestUnlabeled": ("PullRequestUnlabeled",),
        "WebhookPullRequestUnlocked": ("PullRequestUnlocked",),
        "WebhookRegistryPackagePublished": ("RegistryPackagePublished",),
        "WebhookRegistryPackageUpdated": ("RegistryPackageUpdated",),
        "WebhookReleaseCreated": ("ReleaseCreated",),
        "WebhookReleaseDeleted": ("ReleaseDeleted",),
        "WebhookReleaseEdited": ("ReleaseEdited",),
        "WebhookReleasePrereleased": ("ReleasePrereleased",),
        "WebhookReleasePublished": ("ReleasePublished",),
        "WebhookReleaseReleased": ("ReleaseReleased",),
        "WebhookReleaseUnpublished": ("ReleaseUnpublished",),
        "WebhookRepositoryAdvisoryPublished": ("RepositoryAdvisoryPublished",),
        "WebhookRepositoryAdvisoryReported": ("RepositoryAdvisoryReported",),
        "WebhookRepositoryArchived": ("RepositoryArchived",),
        "WebhookRepositoryCreated": ("RepositoryCreated",),
        "WebhookRepositoryDeleted": ("RepositoryDeleted",),
        "WebhookRepositoryDispatchSample": ("RepositoryDispatchSample",),
        "WebhookRepositoryEdited": ("RepositoryEdited",),
        "WebhookRepositoryPrivatized": ("RepositoryPrivatized",),
        "WebhookRepositoryPublicized": ("RepositoryPublicized",),
        "WebhookRepositoryRenamed": ("RepositoryRenamed",),
        "WebhookRepositoryRulesetCreated": ("RepositoryRulesetCreated",),
        "WebhookRepositoryRulesetDeleted": ("RepositoryRulesetDeleted",),
        "WebhookRepositoryRulesetEdited": ("RepositoryRulesetEdited",),
        "WebhookRepositoryTransferred": ("RepositoryTransferred",),
        "WebhookRepositoryUnarchived": ("RepositoryUnarchived",),
        "WebhookRepositoryVulnerabilityAlertCreate": (
            "RepositoryVulnerabilityAlertCreate",
        ),
        "WebhookRepositoryVulnerabilityAlertDismiss": (
            "RepositoryVulnerabilityAlertDismiss",
        ),
        "WebhookRepositoryVulnerabilityAlertReopen": (
            "RepositoryVulnerabilityAlertReopen",
        ),
        "WebhookRepositoryVulnerabilityAlertResolve": (
            "RepositoryVulnerabilityAlertResolve",
        ),
        "WebhookSecretScanningAlertAssigned": ("SecretScanningAlertAssigned",),
        "WebhookSecretScanningAlertCreated": ("SecretScanningAlertCreated",),
        "WebhookSecretScanningAlertLocationCreated": (
            "SecretScanningAlertLocationCreated",
        ),
        "WebhookSecretScanningAlertPubliclyLeaked": (
            "SecretScanningAlertPubliclyLeaked",
        ),
        "WebhookSecretScanningAlertReopened": ("SecretScanningAlertReopened",),
        "WebhookSecretScanningAlertResolved": ("SecretScanningAlertResolved",),
        "WebhookSecretScanningAlertUnassigned": ("SecretScanningAlertUnassigned",),
        "WebhookSecretScanningAlertValidated": ("SecretScanningAlertValidated",),
        "WebhookSecretScanningScanCompleted": ("SecretScanningScanCompleted",),
        "WebhookSecurityAdvisoryPublished": ("SecurityAdvisoryPublished",),
        "WebhookSecurityAdvisoryUpdated": ("SecurityAdvisoryUpdated",),
        "WebhookSecurityAdvisoryWithdrawn": ("SecurityAdvisoryWithdrawn",),
        "WebhookSponsorshipCancelled": ("SponsorshipCancelled",),
        "WebhookSponsorshipCreated": ("SponsorshipCreated",),
        "WebhookSponsorshipEdited": ("SponsorshipEdited",),
        "WebhookSponsorshipPendingCancellation": ("SponsorshipPendingCancellation",),
        "WebhookSponsorshipPendingTierChange": ("SponsorshipPendingTierChange",),
        "WebhookSponsorshipTierChanged": ("SponsorshipTierChanged",),
        "WebhookStarCreated": ("StarCreated",),
        "WebhookStarDeleted": ("StarDeleted",),
        "WebhookSubIssuesParentIssueAdded": ("SubIssuesParentIssueAdded",),
        "WebhookSubIssuesParentIssueRemoved": ("SubIssuesParentIssueRemoved",),
        "WebhookSubIssuesSubIssueAdded": ("SubIssuesSubIssueAdded",),
        "WebhookSubIssuesSubIssueRemoved": ("SubIssuesSubIssueRemoved",),
        "WebhookTeamAddedToRepository": ("TeamAddedToRepository",),
        "WebhookTeamCreated": ("TeamCreated",),
        "WebhookTeamDeleted": ("TeamDeleted",),
        "WebhookTeamEdited": ("TeamEdited",),
        "WebhookTeamRemovedFromRepository": ("TeamRemovedFromRepository",),
        "WebhookWatchStarted": ("WatchStarted",),
        "WebhookWorkflowJobCompleted": ("WorkflowJobCompleted",),
        "WebhookWorkflowJobInProgress": ("WorkflowJobInProgress",),
        "WebhookWorkflowJobQueued": ("WorkflowJobQueued",),
        "WebhookWorkflowJobWaiting": ("WorkflowJobWaiting",),
        "WebhookWorkflowRunCompleted": ("WorkflowRunCompleted",),
        "WebhookWorkflowRunInProgress": ("WorkflowRunInProgress",),
        "WebhookWorkflowRunRequested": ("WorkflowRunRequested",),
        "WorkflowDispatchEvent": ("WorkflowDispatch",),
        "WorkflowJobEvent": ("WorkflowJob",),
        "WorkflowRunEvent": ("WorkflowRun",),
    }

__all__: tuple[str, ...] = (
    "Any",
    "BranchProtectionConfiguration",
    "BranchProtectionConfigurationDisabled",
    "BranchProtectionConfigurationEnabled",
    "BranchProtectionRule",
    "BranchProtectionRuleCreated",
    "BranchProtectionRuleDeleted",
    "BranchProtectionRuleEdited",
    "CheckRun",
    "CheckRunCompleted",
    "CheckRunCreated",
    "CheckRunRequestedAction",
    "CheckRunRerequested",
    "CheckSuite",
    "CheckSuiteCompleted",
    "CheckSuiteRequested",
    "CheckSuiteRerequested",
    "CodeScanningAlert",
    "CodeScanningAlertAppearedInBranch",
    "CodeScanningAlertClosedByUser",
    "CodeScanningAlertCreated",
    "CodeScanningAlertFixed",
    "CodeScanningAlertReopened",
    "CodeScanningAlertReopenedByUser",
    "CodeScanningAlertUpdatedAssignment",
    "CommitComment",
    "CommitCommentCreated",
    "Create",
    "CustomProperty",
    "CustomPropertyCreated",
    "CustomPropertyDeleted",
    "CustomPropertyPromoteToEnterprise",
    "CustomPropertyUpdated",
    "CustomPropertyValues",
    "CustomPropertyValuesUpdated",
    "Delete",
    "DependabotAlert",
    "DependabotAlertAssigneesChanged",
    "DependabotAlertAutoDismissed",
    "DependabotAlertAutoReopened",
    "DependabotAlertCreated",
    "DependabotAlertDismissed",
    "DependabotAlertFixed",
    "DependabotAlertReintroduced",
    "DependabotAlertReopened",
    "DeployKey",
    "DeployKeyCreated",
    "DeployKeyDeleted",
    "Deployment",
    "DeploymentCreated",
    "DeploymentProtectionRule",
    "DeploymentProtectionRuleRequested",
    "DeploymentReview",
    "DeploymentReviewApproved",
    "DeploymentReviewRejected",
    "DeploymentReviewRequested",
    "DeploymentStatus",
    "DeploymentStatusCreated",
    "Discussion",
    "DiscussionAnswered",
    "DiscussionCategoryChanged",
    "DiscussionClosed",
    "DiscussionComment",
    "DiscussionCommentCreated",
    "DiscussionCommentDeleted",
    "DiscussionCommentEdited",
    "DiscussionCreated",
    "DiscussionDeleted",
    "DiscussionEdited",
    "DiscussionLabeled",
    "DiscussionLocked",
    "DiscussionPinned",
    "DiscussionReopened",
    "DiscussionTransferred",
    "DiscussionUnanswered",
    "DiscussionUnlabeled",
    "DiscussionUnlocked",
    "DiscussionUnpinned",
    "Fork",
    "GithubAppAuthorization",
    "GithubAppAuthorizationRevoked",
    "Gollum",
    "Installation",
    "InstallationCreated",
    "InstallationDeleted",
    "InstallationNewPermissionsAccepted",
    "InstallationRepositories",
    "InstallationRepositoriesAdded",
    "InstallationRepositoriesRemoved",
    "InstallationSuspend",
    "InstallationTarget",
    "InstallationTargetRenamed",
    "InstallationUnsuspend",
    "IssueComment",
    "IssueCommentCreated",
    "IssueCommentDeleted",
    "IssueCommentEdited",
    "IssueCommentPinned",
    "IssueCommentUnpinned",
    "IssueDependencies",
    "IssueDependenciesBlockedByAdded",
    "IssueDependenciesBlockedByRemoved",
    "IssueDependenciesBlockingAdded",
    "IssueDependenciesBlockingRemoved",
    "Issues",
    "IssuesAssigned",
    "IssuesClosed",
    "IssuesDeleted",
    "IssuesDemilestoned",
    "IssuesEdited",
    "IssuesLabeled",
    "IssuesLocked",
    "IssuesMilestoned",
    "IssuesOpened",
    "IssuesPinned",
    "IssuesReopened",
    "IssuesTransferred",
    "IssuesTyped",
    "IssuesUnassigned",
    "IssuesUnlabeled",
    "IssuesUnlocked",
    "IssuesUnpinned",
    "IssuesUntyped",
    "Label",
    "LabelCreated",
    "LabelDeleted",
    "LabelEdited",
    "MarketplacePurchase",
    "MarketplacePurchaseCancelled",
    "MarketplacePurchaseChanged",
    "MarketplacePurchasePendingChange",
    "MarketplacePurchasePendingChangeCancelled",
    "MarketplacePurchasePurchased",
    "Member",
    "MemberAdded",
    "MemberEdited",
    "MemberRemoved",
    "Membership",
    "MembershipAdded",
    "MembershipRemoved",
    "MergeGroup",
    "MergeGroupChecksRequested",
    "MergeGroupDestroyed",
    "Meta",
    "MetaDeleted",
    "Milestone",
    "MilestoneClosed",
    "MilestoneCreated",
    "MilestoneDeleted",
    "MilestoneEdited",
    "MilestoneOpened",
    "OrgBlock",
    "OrgBlockBlocked",
    "OrgBlockUnblocked",
    "Organization",
    "OrganizationDeleted",
    "OrganizationMemberAdded",
    "OrganizationMemberInvited",
    "OrganizationMemberRemoved",
    "OrganizationRenamed",
    "Package",
    "PackagePublished",
    "PackageUpdated",
    "PageBuild",
    "PersonalAccessTokenRequest",
    "PersonalAccessTokenRequestApproved",
    "PersonalAccessTokenRequestCancelled",
    "PersonalAccessTokenRequestCreated",
    "PersonalAccessTokenRequestDenied",
    "Ping",
    "Project",
    "ProjectCard",
    "ProjectCardConverted",
    "ProjectCardCreated",
    "ProjectCardDeleted",
    "ProjectCardEdited",
    "ProjectCardMoved",
    "ProjectClosed",
    "ProjectColumn",
    "ProjectColumnCreated",
    "ProjectColumnDeleted",
    "ProjectColumnEdited",
    "ProjectColumnMoved",
    "ProjectCreated",
    "ProjectDeleted",
    "ProjectEdited",
    "ProjectReopened",
    "ProjectsV2",
    "ProjectsV2Item",
    "ProjectsV2ItemArchived",
    "ProjectsV2ItemConverted",
    "ProjectsV2ItemCreated",
    "ProjectsV2ItemDeleted",
    "ProjectsV2ItemEdited",
    "ProjectsV2ItemReordered",
    "ProjectsV2ItemRestored",
    "ProjectsV2ProjectClosed",
    "ProjectsV2ProjectCreated",
    "ProjectsV2ProjectDeleted",
    "ProjectsV2ProjectEdited",
    "ProjectsV2ProjectReopened",
    "ProjectsV2StatusUpdate",
    "ProjectsV2StatusUpdateCreated",
    "ProjectsV2StatusUpdateDeleted",
    "ProjectsV2StatusUpdateEdited",
    "Public",
    "PullRequest",
    "PullRequestAssigned",
    "PullRequestAutoMergeDisabled",
    "PullRequestAutoMergeEnabled",
    "PullRequestClosed",
    "PullRequestConvertedToDraft",
    "PullRequestDemilestoned",
    "PullRequestDequeued",
    "PullRequestEdited",
    "PullRequestEnqueued",
    "PullRequestLabeled",
    "PullRequestLocked",
    "PullRequestMilestoned",
    "PullRequestOpened",
    "PullRequestReadyForReview",
    "PullRequestReopened",
    "PullRequestReview",
    "PullRequestReviewComment",
    "PullRequestReviewCommentCreated",
    "PullRequestReviewCommentDeleted",
    "PullRequestReviewCommentEdited",
    "PullRequestReviewDismissed",
    "PullRequestReviewEdited",
    "PullRequestReviewSubmitted",
    "PullRequestReviewThread",
    "PullRequestReviewThreadResolved",
    "PullRequestReviewThreadUnresolved",
    "PullRequestSynchronize",
    "PullRequestUnassigned",
    "PullRequestUnlabeled",
    "PullRequestUnlocked",
    "Push",
    "RegistryPackage",
    "RegistryPackagePublished",
    "RegistryPackageUpdated",
    "Release",
    "ReleaseCreated",
    "ReleaseDeleted",
    "ReleaseEdited",
    "ReleasePrereleased",
    "ReleasePublished",
    "ReleaseReleased",
    "ReleaseUnpublished",
    "Repository",
    "RepositoryAdvisory",
    "RepositoryAdvisoryPublished",
    "RepositoryAdvisoryReported",
    "RepositoryArchived",
    "RepositoryCreated",
    "RepositoryDeleted",
    "RepositoryDispatch",
    "RepositoryDispatchSample",
    "RepositoryEdited",
    "RepositoryImport",
    "RepositoryPrivatized",
    "RepositoryPublicized",
    "RepositoryRenamed",
    "RepositoryRuleset",
    "RepositoryRulesetCreated",
    "RepositoryRulesetDeleted",
    "RepositoryRulesetEdited",
    "RepositoryTransferred",
    "RepositoryUnarchived",
    "RepositoryVulnerabilityAlert",
    "RepositoryVulnerabilityAlertCreate",
    "RepositoryVulnerabilityAlertDismiss",
    "RepositoryVulnerabilityAlertReopen",
    "RepositoryVulnerabilityAlertResolve",
    "SecretScanningAlert",
    "SecretScanningAlertAssigned",
    "SecretScanningAlertCreated",
    "SecretScanningAlertLocation",
    "SecretScanningAlertLocationCreated",
    "SecretScanningAlertPubliclyLeaked",
    "SecretScanningAlertReopened",
    "SecretScanningAlertResolved",
    "SecretScanningAlertUnassigned",
    "SecretScanningAlertValidated",
    "SecretScanningScan",
    "SecretScanningScanCompleted",
    "SecurityAdvisory",
    "SecurityAdvisoryPublished",
    "SecurityAdvisoryUpdated",
    "SecurityAdvisoryWithdrawn",
    "SecurityAndAnalysis",
    "Sponsorship",
    "SponsorshipCancelled",
    "SponsorshipCreated",
    "SponsorshipEdited",
    "SponsorshipPendingCancellation",
    "SponsorshipPendingTierChange",
    "SponsorshipTierChanged",
    "Star",
    "StarCreated",
    "StarDeleted",
    "Status",
    "SubIssues",
    "SubIssuesParentIssueAdded",
    "SubIssuesParentIssueRemoved",
    "SubIssuesSubIssueAdded",
    "SubIssuesSubIssueRemoved",
    "Team",
    "TeamAdd",
    "TeamAddedToRepository",
    "TeamCreated",
    "TeamDeleted",
    "TeamEdited",
    "TeamRemovedFromRepository",
    "Watch",
    "WatchStarted",
    "WorkflowDispatch",
    "WorkflowJob",
    "WorkflowJobCompleted",
    "WorkflowJobInProgress",
    "WorkflowJobQueued",
    "WorkflowJobWaiting",
    "WorkflowRun",
    "WorkflowRunCompleted",
    "WorkflowRunInProgress",
    "WorkflowRunRequested",
)



from typing import Any

from githubkit import lazy_module as lm


# HACK: githubkit's lazy module mechanism doesn't seem to support aliases in
# __lazy_vars__. This subclass implements it... may future generations forgive me.
class _MonalistenLazyModule(lm.LazyModule):
    def __getattr__(self, name: str) -> Any:
        if (
            self.__lazy_vars_validated__ is None
            or "__monalisten_sentinel__" not in self.__lazy_vars_mapping__
            or not (original_name := self.__lazy_vars_mapping__.get(name))
        ):
            return super().__getattr__(name)

        m = "webhooks" if original_name.endswith("Event") else "models"
        module = self._get_module(f"githubkit.versions.latest.{m}")
        value = getattr(module, original_name)
        setattr(self, name, value)
        return value


lm.LAZY_MODULES = (*lm.LAZY_MODULES, r"^monalisten\.events$")
lm.LazyModule = _MonalistenLazyModule
lm.apply()

from . import events
from ._core import Monalisten
from ._errors import (
    AuthIssue,
    AuthIssueKind,
    Error,
    MonalistenPreprocessingError,
    MonalistenSetupError,
)

__all__ = (
    "AuthIssue",
    "AuthIssueKind",
    "Error",
    "Monalisten",
    "MonalistenPreprocessingError",
    "MonalistenSetupError",
    "events",
)



from __future__ import annotations

import asyncio
import math
from itertools import count
from typing import TYPE_CHECKING

import httpx
from httpx_sse import ServerSentEvent, aconnect_sse

if TYPE_CHECKING:
    from collections.abc import AsyncIterator


async def aiter_sse_retrying(
    client: httpx.AsyncClient, method: str, url: str
) -> AsyncIterator[ServerSentEvent]:
    last_event_id: str | None = None
    retry_delay = 0.0
    for attempt in count():
        try:
            headers = {"Last-Event-ID": last_event_id} if last_event_id else {}
            async with aconnect_sse(client, method, url, headers=headers) as stream:
                async for sse in stream.aiter_sse():
                    last_event_id = sse.id
                    retry_delay = (sse.retry or 0) / 1000
                    yield sse
                break
        except httpx.ReadError:
            await asyncio.sleep(retry_delay + 2 ** (min(attempt, 10) / math.e))



from __future__ import annotations

import asyncio
from itertools import chain
from typing import TYPE_CHECKING, Any, cast, final

import httpx
from githubkit import webhooks
from pydantic import ValidationError

from monalisten._errors import (
    AuthIssue,
    AuthIssueKind,
    Error,
    MonalistenPreprocessingError,
)
from monalisten._event_namespace import EventNamespace
from monalisten._namespace import InternalNamespace
from monalisten._sse import aiter_sse_retrying

if TYPE_CHECKING:
    from collections.abc import Iterable

    from typing_extensions import ParamSpec

    from monalisten._errors import EventPayload
    from monalisten._namespace import Hook

    P = ParamSpec("P")

EVENT_HEADER = "x-github-event"
SIG_HEADER = "x-hub-signature-256"


@final
class Monalisten:
    """
    A Monalisten client streaming events from `source`, optionally secured by the secret
    `token`.
    """

    def __init__(self, source: str, *, token: str | None = None) -> None:
        self._source = source
        self._token = token
        self._event = EventNamespace()
        self._internal = InternalNamespace()

    @property
    def event(self) -> EventNamespace:
        return self._event

    @property
    def internal(self) -> InternalNamespace:
        return self._internal

    @property
    def source(self) -> str:
        return self._source

    @property
    def token(self) -> str | None:
        return self._token

    async def _passes_auth(self, payload: EventPayload) -> bool:
        if not self._token:
            if SIG_HEADER in payload:
                await self._report_auth_issue(AuthIssueKind.UNEXPECTED, payload)
            return True

        if not (signature := payload.get(SIG_HEADER)):
            await self._report_auth_issue(AuthIssueKind.MISSING, payload)
            return False

        if webhooks.verify(self._token, payload["body"], signature):
            return True

        await self._report_auth_issue(AuthIssueKind.MISMATCH, payload)
        return False

    async def _report_auth_issue(
        self, issue_kind: AuthIssueKind, payload: EventPayload
    ) -> None:
        await self._dispatch_hooks(
            payload,
            "auth_issue",
            self.internal["auth_issue"],
            AuthIssue(issue_kind, payload),
        )

    async def _raise(
        self,
        exc: Exception,
        payload: EventPayload | None = None,
        event_name: str | None = None,
    ) -> None:
        if payload:
            event_name = event_name or payload.get(EVENT_HEADER)
        if not (error_hooks := self.internal["error"]):
            raise exc
        await self._dispatch_hooks(
            payload, event_name, error_hooks, Error(exc, event_name, payload)
        )

    async def _handle_payload(
        self, payload: EventPayload, *, skip_auth: bool = False
    ) -> None:
        if not (event_name := payload.get(EVENT_HEADER)):
            msg = f"received data is missing the {EVENT_HEADER} header"
            await self._raise(MonalistenPreprocessingError(msg), payload)
            return

        if not (body := payload.get("body")):
            msg = "received data doesn't contain a body"
            await self._raise(MonalistenPreprocessingError(msg), payload, event_name)
            return

        if not (skip_auth or await self._passes_auth(payload)):
            return

        hook_kinds = [self.event.any["*"], self.event[event_name]["*"]]
        if action := body.get("action"):
            hook_kinds.append(self.event[event_name][action])

        if not (hooks := list(chain.from_iterable(hook_kinds))):
            # Don't parse an event if nothing will handle it anyway
            return

        try:
            webhook_event = webhooks.parse_obj(event_name, body)
        except ValidationError as pydantic_exc:
            msg = "the received payload could not be parsed as an event"
            exc = MonalistenPreprocessingError(msg)
            exc.__cause__ = pydantic_exc
            await self._raise(exc, payload, event_name)
            return

        await self._dispatch_hooks(payload, event_name, hooks, webhook_event)

    async def listen(self) -> None:
        """Start an internal HTTP client and stream events from `source`."""
        async with httpx.AsyncClient(timeout=None) as client:
            await self._dispatch_hooks(
                None, "ready", cast("list[Hook[[]]]", self.internal["ready"])
            )
            async for event in aiter_sse_retrying(client, "GET", self._source):
                if payload := {k.casefold(): v for k, v in event.json().items()}:
                    await self._handle_payload(cast("EventPayload", payload))

    async def dispatch_event(
        self,
        event_type: str,
        body: dict[str, Any],
        *,
        headers: dict[str, Any] | None = None,
    ) -> None:
        """
        Dispatch a webhook event directly to registered hooks.

        Useful for testing hooks without a real GitHub webhook or SSE relay.
        Authentication is skipped by default; set a signature header to test it.
        """
        payload = {EVENT_HEADER: event_type, "body": body} | {
            k.casefold(): v for k, v in (headers or {}).items()
        }
        await self._handle_payload(
            cast("EventPayload", payload), skip_auth=SIG_HEADER not in payload
        )

    async def _dispatch_hooks(
        self,
        payload: EventPayload | None,
        event_name: str | None,
        hooks: Iterable[Hook[P]] | None,
        *args: P.args,
        **kwargs: P.kwargs,
    ) -> None:
        if hooks is None:
            return
        coros = (h(*args, **kwargs) for h in hooks)
        excs = await asyncio.gather(*coros, return_exceptions=True)
        for exc in filter(None, excs):
            if not isinstance(exc, Exception):
                # Don't handle non-Exceptions (like SystemExit or KeyboardInterrupt)
                raise exc
            await self._raise(exc, payload, event_name)



from __future__ import annotations

from enum import Enum
from typing import Any, NamedTuple, TypedDict

EventPayload = TypedDict(
    "EventPayload",
    {
        "body": dict[str, Any],
        # This only lists headers that GitHub considers special; others may be present.
        "x-github-hook-id": str,
        "x-github-event": str,
        "x-github-delivery": str,
        "x-hub-signature": str,
        "x-hub-signature-256": str,
        "user-agent": str,
        "x-github-hook-installation-target-type": str,
        "x-github-hook-installation-target-id": str,
    },
)


class AuthIssueKind(Enum):
    MISSING = "missing"
    """Client has set token, but no signature was received."""
    UNEXPECTED = "unexpected"
    """Client has no set token, but a signature was received."""
    MISMATCH = "mismatch"
    """Client's token couldn't verify received signature."""


class AuthIssue(NamedTuple):
    """An object representing auth issue events reported by the Monalisten client."""

    kind: AuthIssueKind
    payload: EventPayload


class MonalistenPreprocessingError(Exception):
    """Exception for preprocessing errors encountered by the Monalisten client."""


class MonalistenSetupError(Exception):
    """Exception for Monalisten errors occurring before client creation."""


class Error(NamedTuple):
    """An object representing runtime error events reported by the Monalisten client."""

    exc: Exception
    event_name: str | None
    payload: EventPayload | None



from __future__ import annotations

from typing import (
    TYPE_CHECKING,
    Any,
    Generic,
    Literal,
    NoReturn,
    ParamSpec,
    TypeAlias,
    TypeVar,
    cast,
    final,
)

from monalisten._errors import Error, MonalistenSetupError

if TYPE_CHECKING:
    from collections.abc import Awaitable, Callable

    from typing_extensions import Self

    from monalisten._errors import AuthIssue

E = TypeVar("E")
L = TypeVar("L", bound=str)
P = ParamSpec("P")
InternalEventName = Literal["ready", "auth_issue", "error"]
Hook: TypeAlias = "Callable[P, Awaitable[None]]"
HookWrapper: TypeAlias = "Callable[[Hook[P]], Hook[P]]"


def build_registrar(name: str) -> HookWrapper[...]:
    @property
    def prop(self: HookNamespace[Any, E]) -> Callable[[Hook[[E]]], Hook[[E]]]:
        def wrapper(hook: Hook[[E]]) -> Hook[[E]]:
            self._paths[name].append(hook)  # pyright: ignore[reportPrivateUsage]
            return hook

        return wrapper

    return cast("HookWrapper[...]", prop)


class HookNamespace(Generic[L, E]):
    def __init_subclass__(cls) -> None:
        super().__init_subclass__()
        actions = [cast("L", entry) for entry in dir(cls) if not entry.startswith("_")]

        def filling_init(self: Self) -> None:
            self._paths = {a: [] for a in actions}
            self._event_hooks = []

        cls.__init__ = filling_init

    def __init__(self) -> None:
        self._paths: dict[L, list[Hook[[E]]]] = {}
        self._event_hooks: list[Hook[[E]]] = []

    def __call__(self, hook: Hook[[E]]) -> Hook[[E]]:
        self._event_hooks.append(hook)
        return hook

    def __getitem__(self, name: L | Literal["*"]) -> list[Hook[[E]]]:
        if name == "*":
            return self._event_hooks
        return self._paths[name]


@final
class InternalNamespace(HookNamespace[InternalEventName, object]):
    ready: HookWrapper[[]] = build_registrar("ready")
    auth_issue: HookWrapper[[AuthIssue]] = build_registrar("auth_issue")
    error: HookWrapper[[Error]] = build_registrar("error")

    def __call__(self, _: object) -> NoReturn:
        msg = (
            "bare @Monalisten.internal is not allowed, please specify a concrete"
            " internal event"
        )
        raise MonalistenSetupError(msg)
